<?php

namespace HCM\Geral\Controllers;

use Zeedhi\Framework\Controller\Crud;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use HCM\Util\HCMParameters;
use HCM\Util\Repositories;
use HCM\Util\Messages;

class CalendarioController extends Crud {

    protected $CalendarioService;
    protected $dataSourceName = 'calendario';
    protected $dataSourceName1 = 'ocorcalendario_get';
    
    protected $parameterBagColumns = array('P_NRORG', 'P_NRORG_PADRAO');
    public function __construct (Manager $dataSourceManager, ParameterBag $parameterBag, HCMParameters $hcmParameters, \HCM\Geral\Services\CalendarioService $CalendarioService){
        $this->parameterBag = $parameterBag;
        $this->hcmParameters = $hcmParameters;
        $this->calendarioService = $CalendarioService;
        parent::__construct($dataSourceManager);
    }

    public function getCalendario(DTO\Request\Filter $request, DTO\Response $response) {
        $filterData = $request->getFilterCriteria();
        $filterData->setDataSourceName($this->dataSourceName);
        $newFilterData = $this->populateParameterBag($filterData);
        $dataSet = $this->dataSourceManager->findBy($newFilterData);
        $response->addDataSet($dataSet);
    }
    
    public function getFeriado(DTO\Request\Filter $request, DTO\Response $response) {
        $filterData = $request->getFilterCriteria();
        $filterData->setDataSourceName($this->dataSourceName1);
        $newFilterData = $this->populateParameterBag($filterData);
        $dataSet = $this->dataSourceManager->findBy($newFilterData);
        $response->addDataSet($dataSet);
    }
    
    public function setCalendario(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            foreach ($request->getDataSet()->getRows() as &$row) {
                if (array_key_exists('NRCALENDARIO', $row)) {
                    if ($row['NRCALENDARIO'] === '') {
                       $row['NRCALENDARIO'] = \HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgTrabalho(), 'CALENDARIO', 1, 12, true); 
                    }
                } else {
                    $row['NRCALENDARIO'] = \HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgTrabalho(), 'CALENDARIO', 1, 12, true); 
                }
                
            }
            parent::save($request, $response);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function setFeriado(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            $this->dataSourceName = "ocorcalendario";
            foreach ($request->getDataSet()->getRows() as &$row) {
                if (array_key_exists('NROCORCALEND', $row)) {
                    if ($row['NROCORCALEND'] === '') {
                        $row['NROCORCALEND'] = \HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgTrabalho(), 'OCORCALENDARIO', 1, 12, true); 
                    }
                } else {
                    $row['NROCORCALEND'] = \HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgTrabalho(), 'OCORCALENDARIO', 1, 12, true); 
                }
                if(!array_key_exists('NRTPCALENDARIO', $row)){
                    $row['NRTPCALENDARIO'] = null;
                }
            }
            parent::save($request, $response);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function deleteCalendario(DTO\Request\DataSet $request, DTO\Response $response){
        try {
            $dataset = $request->getDataSet()->getRows();
            $dataset = $dataset[0];
            $this->calendarioService->deleteCalendario($dataset);
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('delete', array(true)));
        } catch(\Exception $e) {
            if ($e->getCode() === 10) {
                $response->addMessage(new \Zeedhi\Framework\DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
            }  
            else {
                $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
 	        }
        }
    }
    
    public function deleteFeriado(DTO\Request\DataSet $request, DTO\Response $response){
        $this->dataSourceName = "ocorcalendario";
        parent::delete($request, $response);
    }

    protected function processConditionValue($condition) {
        return $condition['value'];
    }
    protected function populateParameterBag(FilterCriteria $filterCriteria) {

        $conditions = array();
        foreach ($filterCriteria->getConditions() as $condition) {
            $columnName = $condition['columnName'];
            if (in_array($columnName, $this->parameterBagColumns)) {
                $this->parameterBag->set($columnName, $this->processConditionValue($condition));
            } else {
                $conditions[] = $condition;
            }
        }
        $newFilterCriteria = new FilterCriteria(
            $filterCriteria->getDataSourceName(),
            $conditions,
            $filterCriteria->getPage(),
            $filterCriteria->getPageSize()
        );
        return $newFilterCriteria;
    }
    
    /*Funções para sincronização e replicação do calendário*/
    
    public function syncCalendarioFeriado (DTO\Request\DataSet $request, DTO\Response $response){
        try {
            $row = $request->getDataSet()->getRows();
            $row = $row[0];
            $msg = $this->calendarioService->syncCalendarioFeriado($row);
            $msg = implode($msg,'<br>');
            $response->addMessage(new \Zeedhi\Framework\DTO\Response\Message($msg, \Zeedhi\Framework\DTO\Response\Message::TYPE_MESSAGE));
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function replicaCalendario(DTO\Request\DataSet $request, DTO\Response $response){
        try{
            $row = $request->getDataSet()->getRows();
            $row = $row[0];
            
            $msg = $this->calendarioService->replicaCalendario($row);
            $msg = implode($msg, '<br>');
            
            $response->addMessage(new \Zeedhi\Framework\DTO\Response\Message($msg, \Zeedhi\Framework\DTO\Response\Message::TYPE_MESSAGE));
        }catch(\Exception $e){
             $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

} 