<?php

namespace HCM\Geral\Entity;

use HCM\Util\Repositories;      
use HCM\Util\Util;
use HCM\Util\FPA;
use HCM\Util\TkEntity;

class EnderecoparcEntity extends TkEntity
{

    private $_nrEndereco;

    private $_endereco;
    private $_numero;
    private $_complemento;
    private $_nrOrg;
    private $_nrOrgPadrao;

    public function __construct($entityManager, $hcmParameters){

        parent::__construct(null, $entityManager);
        $this->entityManager = $entityManager;
        $this->hcmParameters = $hcmParameters;
        $this->_nrOrg = $hcmParameters->getNrorgTrabalho();
        $this->_nrOrgPadrao = $hcmParameters->getNrorgPadrao();
    }

	public static function novoCodigo(){
		
		return Enderecoparc::novoCodigo();
		
		
	}
	
	public static function deleta_filho_enderecoparc($nrenderecoparc){		
		try{
		    Enderecoparc::deleta_filho_enderecoparc($nrenderecoparc);
        } catch(Exception $e) {
            throw $e;
        }
			
	}
	
	public static function validaCdTipoEndereco($nrparcnegocio, $nrenderecoparc, $novoisnull = null){
		try{
                    return Enderecoparc::validaCdTipoEndereco($nrparcnegocio, $nrenderecoparc, $novoisnull);
                }catch(Exception $e){
                    throw $e;
                }
		
	}
	
	public static function verificaSeENovo($nrenderecoparc){
				
		return Enderecoparc::verificaSeENovo($nrenderecoparc);
		
	}


    /**
     * Retorna uma instancia de EnderecoparcEntity
     *
     * @param string $nrEnderecoParc Numero do EnderecoParc.
     * @param string $nrOrg          Numero da Organizacao.
     *
     * @return EnderecoparcEntity | null
     *
     * @author thalesvalias - 02/04/2012
     */
    public function retornaEnderecoParceiro($nrEnderecoParc, $nrOrg){
        $enderecoParc = Enderecoparc::retornaEnderecoParceiro($nrEnderecoParc, $nrOrg);

        return $enderecoParc;
    }


    /**
     * Retorna uma instancia de EnderecoparcEntity por tipo de endereco
     *
     * @param integer $nrOrg        Numero da Organizacao.
     * @param integer $nrParceiro   Numero do EnderecoParc.
     * @param string  $tipoEndereco Tipo de endereco.
     *
     * @return EnderecoparcEntity | null
     *
     * @author thalesvalias - 12/04/2012
     */
    public function retornaEnderecoParceiroPorTipo($nrOrg, $nrParceiro, $tipoEndereco){
        return $this->entityManager->getRepository(Repositories::ENDERECOPARC)->retornaEnderecoParceiroPorTipo(
                $this->_nrOrg, $nrParceiro, $tipoEndereco
            );
    }


    public static function consultaEnderecoPorCep($cep, $nrorg)
    {
        try{
            return Enderecoparc::consultaEnderecoPorCep($cep, $nrorg);
        } catch(PDOException $e) {
            throw $e;
        }
    }

    public function getComplemento() {
        return $this->_complemento;
    }


    public function getEndereco() {
        return $this->_endereco;
    }


    public function getNumero() {
        return $this->_numero;
    }

    public function getNrendereco(){
        return $this->_nrEndereco;
    }

    public function criaEnderecoParc(
        $nrOrg, $nrParceiro, $cdTipoEndereco, $cdPais = null, $sgEstado = null, $cdMunicipio = null, $bairro = null,
        $cep = null, $descEndereco = null
    ){
        $endereco = new self();
        $endereco->setNrorg($nrOrg);
        $endereco->setNrparcnegocio($nrParceiro);
        $endereco->setCdtipoendereco($cdTipoEndereco);
        $endereco->setCdpais($cdPais);
        $endereco->setSgestado($sgEstado);
        $endereco->setCdmunicipio($cdMunicipio);
        $endereco->setNmbairroendereco($bairro);
        $endereco->setNrcependereco($cep);
        $endereco->setDsendereco($descEndereco);

        $endereco->persist();

        $this->_nrEndereco = $endereco->getNrenderecoparc();
        unset($endereco);


    }

    public function setEnderecoParceiro($nrorg, $nrparceiro, $cdtipoendereco, $cdpais, $sgestado, $cdmunicipio,
                                           $bairro, $cep, $descEndereco)
    {
        $this->setNrorg($nrorg);
        $this->setNrparcnegocio($nrparceiro);
        $this->setCdtipoendereco($cdtipoendereco);
        $this->setCdpais($cdpais);
        $this->setSgestado($sgestado);
        $this->setCdmunicipio($cdmunicipio);
        $this->setNmbairroendereco($bairro);
        $this->setNrcependereco($cep);
        $this->setDsendereco($descEndereco);
    }

    /**
     * @param $nrorg
     * @param $nrparceiro
     * @return EnderecoparcEntity
     * @autor jorgefonseca
     */
    public static function getEnderecoParceiro($nrorg, $nrparceiro) {
        $enderecoparc = self::getEntityByWhere('NRORG = ? AND NRPARCNEGOCIO = ?', array($nrorg, $nrparceiro));
        return $enderecoparc;
    }

}

