<?php
namespace HCM\Geral\Repository;

use Doctrine\DBAL\Connection;
use Doctrine\ORM\EntityManager;
use HCM\Util\HCMParameters;

class NaoPeriodicosRepository {

    protected  $connection;

    public function __construct(Connection $connection, EntityManager $entityManager, HCMParameters $hcmParameters) {
        $this->connection = $connection;
        $this->entityManager = $entityManager;
        $this->hcmParameters = $hcmParameters;
    }
    
    /**
     * @param $nrenvio
     * @param $nrchave
     * @param $nrestruturam
     * @return array    Associative array
     */
    public function getDadosS2190($nrenvio, $nrchave, $nrestruturam) {
        $sql = <<<SQL
SELECT VM.NRVINCULOM CHAVE,
       'ID'||DECODE(PAR.CDTIPOINSCRICAO,'CNPJ','1','CPF','2','')||RPAD(CASE WHEN EMH.CDNATUJURI IN ('1015','1040','1074','1163') THEN PAR.NRINSCRICAOPARC ELSE SUBSTR(PAR.NRINSCRICAOPARC,1,8) END,14,'0')||TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS')||LPAD(:P_NRENVIO,5,'0') ID,
       --ideEmpregador
       DECODE(PAR.CDTIPOINSCRICAO,'CNPJ','1','CPF','2','') TPINSC,
       CASE WHEN EMH.CDNATUJURI IN ('1015','1040','1074','1163') THEN PAR.NRINSCRICAOPARC ELSE SUBSTR(PAR.NRINSCRICAOPARC,1,8) END NRINSC,   
       --infoRegPrelim
       REPLACE(REPLACE(PH.NRCPFPESSOA, '.'), '-') AS CPFTRAB,  
       PH.DTNASCPESSOA AS dtNascto,
       VM.DTADMISSAOVINC AS dtAdm  
  FROM GPE_VINCULOM VM
  /*Dados do Empregado - Vínculo*/
  JOIN GPE_VINCULOH VH
    ON VH.NRVINCULOM = VM.NRVINCULOM
   AND VH.NRORG      = VM.NRORG
   AND VH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_VINCULOH
                             WHERE GPE_VINCULOH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                               AND GPE_VINCULOH.NRVINCULOM = VM.NRVINCULOM
                               AND GPE_VINCULOH.NRORG = VM.NRORG)
  /*Dados do Empregado - Pessoa*/                               
  JOIN GPE_PESSOA PE
    ON PE.NRPESSOA = VM.NRPESSOA
   AND PE.NRORG    = VM.NRORG
  JOIN GPE_PESSOAH PH
    ON PH.NRPESSOA = PE.NRPESSOA
   AND PH.NRORG    = PE.NRORG
   AND PH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_PESSOAH
                             WHERE GPE_PESSOAH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                               AND GPE_PESSOAH.NRPESSOA = PE.NRPESSOA
                               AND GPE_PESSOAH.NRORG = PE.NRORG)
  JOIN PARCNEGOCIO PN
    ON PN.NRPARCNEGOCIO = PE.NRPARCNEGOCIO
   AND PN.NRORG         = PE.NRORG                               
  /*Empregador*/
  JOIN ESTRUTURAH EMH ON EMH.NRORG = :P_NRORG
                     AND EMH.NRESTRUTURAM = :P_NRESTRUTURAM
                     AND EMH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH
                                               WHERE ESTRUTURAH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                 AND ESTRUTURAH.NRESTRUTURAM = EMH.NRESTRUTURAM
                                                 AND ESTRUTURAH.NRORG = EMH.NRORG)
  JOIN PARCNEGOCIO PAR ON PAR.NRPARCNEGOCIO = EMH.NRPARCNEGOCIO
                      AND PAR.NRORG = EMH.NRORG
 WHERE VM.NRORG = :P_NRORG
   AND VM.NRVINCULOM = :P_NRCHAVE
SQL;
        $params = array(
            "P_NRORG" => $this->hcmParameters->getNrorgTrabalho(),
            "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
            "P_NRENVIO" => $nrenvio,
            "P_NRCHAVE" => $nrchave,
            "P_NRESTRUTURAM" => $nrestruturam
        );
        return $this->connection->fetchAssoc($sql, $params);
    }
    
    /**
     * @param $nrenvio
     * @param $nrchave
     * @param $nrestruturam
     * @return array    Associative array
     */
    public function getDadosS2210($nrenvio, $nrchave, $nrestruturam) {
        $sql = <<<SQL
SELECT VI.NRVITIMA CHAVE,
       'ID'||DECODE(PAR.CDTIPOINSCRICAO,'CNPJ','1','CPF','2','')||RPAD(CASE WHEN EMH.CDNATUJURI IN ('1015','1040','1074','1163') THEN PAR.NRINSCRICAOPARC ELSE SUBSTR(PAR.NRINSCRICAOPARC,1,8) END,14,'0')||TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS')||LPAD(:P_NRENVIO,5,'0') id,
       --idRegistrador
       5 AS tpRegistrador,
       DECODE(PNV.CDTIPOINSCRICAO,'CNPJ','1','CPF','2','') tpInsc,
           CASE WHEN EMH.CDNATUJURI IN ('1015','1040','1074','1163') THEN PNV.NRINSCRICAOPARC ELSE SUBSTR(PNV.NRINSCRICAOPARC,1,8) END AS nrInsc,  
       --ideEmpregador
       DECODE(PAR.CDTIPOINSCRICAO,'CNPJ','1','CPF','2','') ideEmpregador_tpInsc,
           CASE WHEN EMH.CDNATUJURI IN ('1015','1040','1074','1163') THEN PAR.NRINSCRICAOPARC ELSE SUBSTR(PAR.NRINSCRICAOPARC,1,8) END AS ideEmpregador_nrInsc,           
       --ideTrabalhador
       REPLACE(REPLACE(PH.NRCPFPESSOA, '.'), '-') AS CPFTRAB,  
       PH.NRPISPASEPPES AS nisTrab,
       --cat
       OC.DTHROCORRENCIA AS dtAcid,       
       VI.IDACIDFATAL AS tpAcid,
       TO_CHAR(OC.DTHROCORRENCIA, 'HH24MI') AS hrAcid,
       DECODE(VI.DTOBITO, NULL, '') AS indCatObito,
       VI.IDREGPOLICIAL AS indComunPolicia,
       SITG.CDESOCIAL AS codSitGeradora,
       1 AS iniciatCAT,
       OC.DSOBSERVACAO AS observacao,
       --localAcidente
       TLC.CDESOCIAL AS tpLocal,
       VI.DSLOCALCAT AS dscLocal,
       EP.DSENDERECO AS dscLograd,
       EP.NRIMOVELENDERECO AS nrLograd,
       MU.CDMUNICIBGE AS codMunic,
       EP.SGESTADO AS uf,
       ECAT.CDCNPJESTRUT AS cnpjLocalAcid,
       PA.CDESOCIAL AS pais,
       EP.NRCEPENDERECO AS codPostal,
       -- getDadosS2210parteAtingida
       --getDadosS2210agenteCausador       
       --atestado
       EHFM.CODCNES AS codCNES,
       VI.DTHRINICATEND AS dtAtendimento,
       VI.QTHRATENDIMENTO AS hrAtendimento,
       VI.IDINTERNACAO AS indInternacao,
       FM.DTHRINIAFASTAMENTO - DTHRFIMAFASTAMENTO durTrat,
       VI.IDAFASTAMENTO AS indAfast,  
       NL.CDESOCIAL AS dscLesao,
       NL.DSNATUREZALESAO AS dscCompLesao,
       NULL diagProvavel,
       CID.CDCID AS codCID,
       VI.DSOBSERVACAO AS observacao,
       --emitente
       PHFM.NMPESSOA AS nmEmit,
       PHFM.NRCONSELHOREG ideOC,      
       PHFM.NRINSCRCONSREG AS nrOc,
       PHFM.SGUFCONSREG AS ufOC,       
       --catOrigem
       VIANT.DTCAT as dtCatOrig,
       VIANT.NRCAT AS nrCatOrig     
  FROM SST_VITIMA VI
  /*Comunicação de Acidente de Trabalho.*/
  JOIN SST_OCORRENCIA OC ON OC.NROCORRENCIA = VI.NROCORRENCIA AND OC.NRORG = VI.NRORG  
  JOIN SST_TIPOOCORRE TOC ON TOC.NRORG = OC.NRORG AND TOC.NRTIPOOCORRE = OC.NRTIPOOCORRE  
  LEFT JOIN SST_SITUGERADORA SITG ON (SITG.NRORG = TOC.NRORG OR SITG.NRORG = 0) AND SITG.NRSITUGERADORA = TOC.NRSITUGERADORA
  LEFT JOIN SST_TIPOLOCALCAT TLC ON (TLC.NRORG = VI.NRORG OR TLC.NRORG = 0) AND TLC.NRTIPOLOCALCAT = VI.NRTIPOLOCALCAT
  LEFT JOIN SST_NATUREZA N ON (N.NRORG = VI.NRORG OR N.NRORG = 0) AND N.NRNATUREZA = VI.NRNATUREZA
  LEFT JOIN ESO_NATUREZALESAO NL ON (NL.NRORG = N.NRORG OR NL.NRORG = 0) AND NL.NRNATUREZALESAO = N.NRNATUREZALESAO
  /*CAT ORIGEM*/
  LEFT JOIN SST_VITIMA VIANT ON VI.NRORG = VIANT.NRORG AND VI.NRCATORIGEM = VIANT.NRCAT  
  /*LOCAL CAT */
  JOIN ESTRUTURAH ECAT ON ECAT.NRORG = :P_NRORG
                     AND ECAT.NRESTRUTURAM = OC.NRESTRUTURAM
                     AND ECAT.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH
                                                WHERE DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                  AND NRESTRUTURAM = ECAT.NRESTRUTURAM
                                                  AND NRORG = ECAT.NRORG)
  JOIN PARCNEGOCIO PNCAT ON PNCAT.NRPARCNEGOCIO = ECAT.NRPARCRESPINF
                           AND PNCAT.NRORG = ECAT.NRORG
  LEFT JOIN ENDERECOPARC EP ON PNCAT.NRPARCNEGOCIO = EP.NRPARCNEGOCIO
  AND PNCAT.NRORG = EP.NRORG
  AND EP.CDTIPOENDERECO = 'PRINCIPAL'
  /*Dados do Empregado - Dependentes*/                                                
  LEFT JOIN PAIS PA ON PA.CDPAIS = EP.CDPAIS
                   AND (PA.NRORG = EP.NRORG OR PA.NRORG = 0)
  /*Dados do Empregado - Naturalidade*/
  LEFT JOIN MUNICIPIO MU ON MU.CDMUNICIPIO = EP.CDMUNICIPIO
                        AND (MU.NRORG = EP.NRORG OR MU.NRORG = 0)
  
  /*Dados do Empregado*/
  JOIN PARCNEGOCIO PNV ON PNV.NRPARCNEGOCIO = VI.NRPARCNEGOCIO
                           AND PNV.NRORG = VI.NRORG   
  JOIN GPE_PESSOA PE ON PNV.NRPARCNEGOCIO = PE.NRPARCNEGOCIO
                    AND PNV.NRORG    = PE.NRORG
  JOIN GPE_PESSOAH PH ON PE.NRPESSOA = PH.NRPESSOA
                     AND PE.NRORG    = PH.NRORG
                     AND PH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_PESSOAH
                                               WHERE GPE_PESSOAH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                 AND GPE_PESSOAH.NRPESSOA = PH.NRPESSOA
                                                 AND GPE_PESSOAH.NRORG = PH.NRORG)    
  JOIN GPE_VINCULOM VM ON VM.NRORG = VI.NRORG AND VM.NRPESSOA = PE.NRPESSOA
  JOIN GPE_VINCULOEMPREG VE ON VE.NRVINCULOEMPREG = VM.NRVINCULOEMPREG
  LEFT JOIN GPE_CATEGTRABESOC CE ON CE.NRCATEGESOC = VE.NRCATEGESOC
  JOIN GPE_TIPOVINCULOH VT ON VT.NRTIPOVINCULOM = VM.NRTIPOVINCULOM
                          AND (VT.NRORG = VM.NRORG OR VT.NRORG = 0 OR VT.NRORG IS NULL)
                          AND VT.IDVINCULOEMPR = 'S'
                          AND VT.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_TIPOVINCULOH
                                                    WHERE GPE_TIPOVINCULOH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                      AND GPE_TIPOVINCULOH.NRTIPOVINCULOM = VT.NRTIPOVINCULOM
                                                      AND GPE_TIPOVINCULOH.NRORG = VT.NRORG)
  JOIN GPE_VINCULOH VH ON VH.NRVINCULOM = VM.NRVINCULOM
                      AND VH.NRORG = VM.NRORG
                      AND VH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_VINCULOH
                                                WHERE GPE_VINCULOH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                  AND GPE_VINCULOH.NRVINCULOM = VH.NRVINCULOM
                                                  AND GPE_VINCULOH.NRORG = VH.NRORG)
  /*Ficha Medica*/
  LEFT JOIN SST_FICHAMEDICA FM ON VM.NRVINCULOM = FM.NRVINCULOM AND FM.NRCAT = VI.NRCAT
  LEFT JOIN SST_DOENCAFICHAMEDICA DFM ON DFM.NRORG = FM.NRORG AND DFM.NRFICHAMEDICA = FM.NRFICHAMEDICA
  LEFT JOIN SST_CID CID ON CID.NRCID = DFM.NRCID 
  /*Responsavel Ficha Medica*/
  LEFT JOIN ESTRUTURAH EHFM ON EHFM.NRORG = :P_NRORG
                     AND EHFM.NRESTRUTURAM = FM.NRESTRUTURAM
                     AND EHFM.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH
                                                WHERE DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                  AND NRESTRUTURAM = EHFM.NRESTRUTURAM
                                                  AND NRORG = EHFM.NRORG)
  LEFT JOIN GPE_PESSOA PFM ON PNV.NRPARCNEGOCIO = FM.NRPARCNEGOCIO
                    AND PNV.NRORG    = FM.NRORG
  LEFT JOIN GPE_PESSOAH PHFM ON PFM.NRPESSOA = PHFM.NRPESSOA
                     AND PFM.NRORG    = PHFM.NRORG
                     AND PHFM.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_PESSOAH
                                               WHERE GPE_PESSOAH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                 AND GPE_PESSOAH.NRPESSOA = PHFM.NRPESSOA
                                                 AND GPE_PESSOAH.NRORG = PHFM.NRORG)   
  
  /*Local de Trabalho*/
  JOIN ESTRUTURAH ET ON ET.NRESTRUTURAM = VH.NRESTRUTGEREN
                    AND ET.NRORG = VH.NRORG
                    AND ET.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH
                                              WHERE ESTRUTURAH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                AND ESTRUTURAH.NRESTRUTURAM = ET.NRESTRUTURAM
                                                AND ESTRUTURAH.NRORG = ET.NRORG)
  JOIN PARCNEGOCIO PN ON PN.NRPARCNEGOCIO = ET.NRPARCNEGOCIO
                     AND PN.NRORG = ET.NRORG
  LEFT JOIN GPE_CLASSESTRANG CT ON CT.NRCLASSESTRANG = PH.NRCLASSESTRANG 
  /*Empregador*/
  JOIN ESTRUTURAH EMH ON EMH.NRORG = :P_NRORG
                     AND EMH.NRESTRUTURAM = :P_NRESTRUTURAM
                     AND EMH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH
                                                WHERE DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                  AND NRESTRUTURAM = EMH.NRESTRUTURAM
                                                  AND NRORG = EMH.NRORG)
  JOIN PARCNEGOCIO PAR ON PAR.NRPARCNEGOCIO = EMH.NRPARCNEGOCIO
                      AND PAR.NRORG = EMH.NRORG
 WHERE VM.NRORG = :P_NRORG
   AND VH.NRESTRUTLEGAL = :P_NRESTRUTURAM
   AND (VM.DTRESCISAOVINC IS NULL OR VM.DTRESCISAOVINC >= :P_DTMESCOMPETENC)
   AND VI.NRVITIMA = :P_NRCHAVE
SQL;
        $params = array(
            "P_NRORG" => $this->hcmParameters->getNrorgTrabalho(),
            "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
            "P_NRENVIO" => $nrenvio,
            "P_NRCHAVE" => $nrchave,
            "P_NRESTRUTURAM" => $nrestruturam
        );
        return $this->connection->fetchAssoc($sql, $params);
    }
    
    public function getDadosS2210parteAtingida($nrorg, $nrvitima) {
        $sql = <<<SQL
SELECT 
PAE.CDESOCIAL AS codParteAting,
VPA.LATERALIDADE AS lateralidade
FROM SST_VITIMAPARTEATINGIDA VPA
JOIN SST_PARTEATINGIDA PA ON (PA.NRORG = VPA.NRORG OR PA.NRORG = 0) AND PA.NRPARTEATINGIDA = VPA.NRPARTEATINGIDA
JOIN SST_PARTATINGESOC PAE
ON PA.NRPARTATINGESOC = PAE.NRPARTATINGESOC
AND (PAE.NRORG        = PA.NRORG
OR PAE.NRORG          = 0)
WHERE VPA.NRVITIMA = :P_NRVITIMA
AND VPA.NRORG = :P_NRORG
SQL;
        $params = array(
            "P_NRORG" => $nrorg,
            "P_NRVITIMA" => $nrvitima
        );
        return $this->connection->fetchAll($sql, $params);
    }
    
    public function getDadosS2210agenteCausador($nrorg, $nrvitima) {
        $sql = <<<SQL
SELECT AC.CDESOCIAL codAgntCausador
FROM SST_VITIMA VI
LEFT JOIN SST_AGENTCAUSAD AC
ON AC.NRAGENTCAUSAD = VI.NRAGENTCAUSAD
AND (AC.NRORG       = VI.NRORG
OR AC.NRORG         = 0)
WHERE VI.NRORG      = :P_NRORG
AND VI.NRVITIMA     = :P_NRVITIMA
SQL;
        $params = array(
            "P_NRORG" => $nrorg,
            "P_NRVITIMA" => $nrvitima,
            "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
        );
        return $this->connection->fetchAll($sql, $params);
    }
    
    /**
     * @param $nrenvio
     * @param $nrchave
     * @param $nrestruturam
     * @return array    Associative array
     */
    public function getDadosS2220($nrenvio, $nrchave, $nrestruturam) {
        $sql = <<<SQL
SELECT FM.NRFICHAMEDICA CHAVE,
       'ID'||DECODE(PAR.CDTIPOINSCRICAO,'CNPJ','1','CPF','2','')||RPAD(CASE WHEN EMH.CDNATUJURI IN ('1015','1040','1074','1163') THEN PAR.NRINSCRICAOPARC ELSE SUBSTR(PAR.NRINSCRICAOPARC,1,8) END,14,'0')||TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS')||LPAD(:P_NRENVIO,5,'0') ID,
       --ideEmpregador
       DECODE(PAR.CDTIPOINSCRICAO,'CNPJ','1','CPF','2','') TPINSC,
       CASE WHEN EMH.CDNATUJURI IN ('1015','1040','1074','1163') THEN PAR.NRINSCRICAOPARC ELSE SUBSTR(PAR.NRINSCRICAOPARC,1,8) END NRINSC,    
       --ideVinculo
       REPLACE(REPLACE(PH.NRCPFPESSOA, '.'), '-') AS CPFTRAB,  
       PH.NRPISPASEPPES AS nisTrab,
       VM.CDMATRICULA AS matricula,
       --aso
       FM.DTHRPREVFICHAMED AS dtAso,
       NE.CDESOCIAL AS tpAso,
       TRE.IDAPTO AS resAso,   
       --getDadosS2220exame
       --ideServSaude
       EHSSR.CODCNES AS codCNES,       
       (SELECT MAX(C.CDPREFIXCOMUPARC||C.CDCOMUNICAPARC)
          FROM COMUNICAPARC C
         WHERE C.NRPARCNEGOCIO = EMSSR.NRPARCNEGOCIO
           AND C.NRORG = EMSSR.NRORG
           AND C.CDFORMACOMU = '01') frmCtt, --Telefone principal,     
       (SELECT MAX(C.CDCOMUNICAPARC)
          FROM COMUNICAPARC C
         WHERE C.NRPARCNEGOCIO = EMSSR.NRPARCNEGOCIO
           AND C.NRORG = EMSSR.NRORG
           AND C.CDFORMACOMU = '05') email, -- email      
       PHRM.NMPESSOA AS nmMed,
       PHRM.NRINSCRCONSREG AS nrCRM,
       PHRM.SGUFCONSREG AS ufCRM
  FROM SST_FICHAMEDICA FM 
  /*EXAME*/
  LEFT JOIN SST_NATUREZAEXAME NE ON (NE.NRORG = FM.NRORG OR NE.NRORG = 0) AND NE.NRNATUREZAEXAME = FM.NRNATUREZAEXAME
  LEFT JOIN SST_TABRESULTEXAME TRE ON (TRE.NRORG = FM.NRORG OR TRE.NRORG = 0) AND TRE.NRTABRESULTEXAME = FM.NRTABRESULTEXAME
  /*Serviço de Saude Responsavel*/
  LEFT JOIN ESTRUTURAM EMSSR ON EMSSR.NRORG = :P_NRORG AND EMSSR.NRESTRUTURAM = FM.NRESTRUTURAM
  LEFT JOIN ESTRUTURAH EHSSR ON EHSSR.NRORG = :P_NRORG
                     AND EHSSR.NRESTRUTURAM = FM.NRESTRUTURAM
                     AND EHSSR.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH
                                               WHERE ESTRUTURAH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                 AND ESTRUTURAH.NRESTRUTURAM = EHSSR.NRESTRUTURAM
                                                 AND ESTRUTURAH.NRORG = EHSSR.NRORG)
  /*Medico Responsavel*/
  LEFT JOIN GPE_PESSOA PRM ON PRM.NRPARCNEGOCIO = FM.NRPARCNEGOCIO
                    AND PRM.NRORG    = FM.NRORG
  LEFT JOIN GPE_PESSOAH PHRM ON PRM.NRPESSOA = PHRM.NRPESSOA
                     AND PRM.NRORG    = PHRM.NRORG
                     AND PHRM.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_PESSOAH
                                               WHERE GPE_PESSOAH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                 AND GPE_PESSOAH.NRPESSOA = PHRM.NRPESSOA
                                                 AND GPE_PESSOAH.NRORG = PHRM.NRORG)

  /*Dados do Empregado - Vínculo*/
  JOIN GPE_VINCULOM VM ON FM.NRVINCULOM = VM.NRVINCULOM AND VM.NRORG = FM.NRORG
  JOIN GPE_VINCULOH VH
    ON VH.NRVINCULOM = VM.NRVINCULOM
   AND VH.NRORG      = VM.NRORG
   AND VH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_VINCULOH
                             WHERE GPE_VINCULOH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                               AND GPE_VINCULOH.NRVINCULOM = VM.NRVINCULOM
                               AND GPE_VINCULOH.NRORG = VM.NRORG)
  /*Dados do Empregado - Pessoa*/                               
  JOIN GPE_PESSOA PE
    ON PE.NRPESSOA = VM.NRPESSOA
   AND PE.NRORG    = VM.NRORG
  JOIN GPE_PESSOAH PH
    ON PH.NRPESSOA = PE.NRPESSOA
   AND PH.NRORG    = PE.NRORG
   AND PH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_PESSOAH
                             WHERE GPE_PESSOAH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                               AND GPE_PESSOAH.NRPESSOA = PE.NRPESSOA
                               AND GPE_PESSOAH.NRORG = PE.NRORG)
  JOIN PARCNEGOCIO PN
    ON PN.NRPARCNEGOCIO = PE.NRPARCNEGOCIO
   AND PN.NRORG         = PE.NRORG                               
  /*Empregador*/
  JOIN ESTRUTURAH EMH ON EMH.NRORG = :P_NRORG
                     AND EMH.NRESTRUTURAM = :P_NRESTRUTURAM
                     AND EMH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH
                                               WHERE ESTRUTURAH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                 AND ESTRUTURAH.NRESTRUTURAM = EMH.NRESTRUTURAM
                                                 AND ESTRUTURAH.NRORG = EMH.NRORG)
  JOIN PARCNEGOCIO PAR ON PAR.NRPARCNEGOCIO = EMH.NRPARCNEGOCIO
                      AND PAR.NRORG = EMH.NRORG
 WHERE FM.NRORG = :P_NRORG
   AND FM.NRFICHAMEDICA = :P_NRCHAVE
SQL;
        $params = array(
            "P_NRORG" => $this->hcmParameters->getNrorgTrabalho(),
            "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
            "P_NRENVIO" => $nrenvio,
            "P_NRCHAVE" => $nrchave,
            "P_NRESTRUTURAM" => $nrestruturam
        );
        return $this->connection->fetchAssoc($sql, $params);
    }
    
    public function getDadosS2220exame($nrorg, $estrutGerencial, $nrfichamedica) {
        $sql = <<<SQL
SELECT EFM.DTREALIZACAOEXAME                AS dtExm,
  EFM.CDPROCTUSS                            AS procRealizado,
  EFM.OBSPROCTUSS                           AS obsProc,
  EFM.INTERPREXAME                          AS interprExm,
  DECODE(EFM.IDEXAMEREFSEQ, 'R', 1, 'S', 2) AS ordExame,
  EFM.DTREALIZACAOEXAME                     AS dtIniMonit,
  NULL dtFimMonit,
  DECODE(TRE.IDRESULTEXAME, 'N', 1, 'A', 2,'E', 3, 'G', 4) indResult,
  --respMonit
  PARAMB.NRINSCRICAOPARC AS nisResp,       
  PHAMB.NRINSCRCONSREG AS nrOc,
  PHAMB.SGUFCONSREG AS ufOC   
FROM SST_EXAMEFICHAMED EFM
LEFT JOIN SST_TABRESULTEXAME TRE
ON (TRE.NRORG            = EFM.NRORG
OR TRE.NRORG             = 0)
AND TRE.NRTABRESULTEXAME = EFM.NRTABRESULTEXAME
 JOIN SST_FICHAMEDICA FM ON FM.NRFICHAMEDICA = EFM.NRFICHAMEDICA AND FM.NRORG = EFM.NRORG
 JOIN ESTRUTURAH EMH ON EMH.NRORG = :P_NRORG
                     AND EMH.NRESTRUTURAM = :P_NRESTRUTGEREN
                     AND EMH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH
                                               WHERE ESTRUTURAH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                 AND ESTRUTURAH.NRESTRUTURAM = EMH.NRESTRUTURAM
                                                 AND ESTRUTURAH.NRORG = EMH.NRORG)
 /*Parceiro Biologico*/                                                 
 LEFT JOIN PARCNEGOCIO PARAMB ON PARAMB.NRPARCNEGOCIO = EMH.NRPARCMONBIO
                      AND PARAMB.NRORG = EMH.NRORG
 LEFT JOIN GPE_PESSOA PAMB
    ON PAMB.NRPARCNEGOCIO = PARAMB.NRPARCNEGOCIO
   AND PAMB.NRORG    = FM.NRORG
 LEFT JOIN GPE_PESSOAH PHAMB
    ON PHAMB.NRPESSOA = PAMB.NRPESSOA
   AND PHAMB.NRORG    = FM.NRORG
   AND PHAMB.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_PESSOAH
                             WHERE GPE_PESSOAH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                               AND GPE_PESSOAH.NRPESSOA = PHAMB.NRPESSOA
                               AND GPE_PESSOAH.NRORG = PHAMB.NRORG)  



WHERE EFM.NRORG          = :P_NRORG
AND EFM.NRFICHAMEDICA    = :P_NRCHAVE
SQL;
        $params = array(
            "P_NRORG" => $nrorg,
            "P_NRCHAVE" => $nrfichamedica,
            "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
            "P_NRESTRUTGEREN" => $estrutGerencial
        );
        return $this->connection->fetchAll($sql, $params);
    }
    
    /**
     * @param $nrenvio
     * @param $nrchave
     * @param $nrestruturam
     * @return array    Associative array
     */
    public function getDadosS2230($nrenvio, $nrchave, $nrestruturam) {
        $sql = <<<SQL
SELECT ASF.NRALTESITUFUNC CHAVE,
       'ID'||DECODE(PAR.CDTIPOINSCRICAO,'CNPJ','1','CPF','2','')||RPAD(CASE WHEN EMH.CDNATUJURI IN ('1015','1040','1074','1163') THEN PAR.NRINSCRICAOPARC ELSE SUBSTR(PAR.NRINSCRICAOPARC,1,8) END,14,'0')||TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS')||LPAD(:P_NRENVIO,5,'0') ID,
       --ideEmpregador
       DECODE(PAR.CDTIPOINSCRICAO,'CNPJ','1','CPF','2','') TPINSC,
       CASE WHEN EMH.CDNATUJURI IN ('1015','1040','1074','1163') THEN PAR.NRINSCRICAOPARC ELSE SUBSTR(PAR.NRINSCRICAOPARC,1,8) END NRINSC,
       --ideVinculo
       REPLACE(REPLACE(PH.NRCPFPESSOA, '.'), '-') AS CPFTRAB,       
       PH.NRPISPASEPPES AS NISTRAB,
       VM.NRVINCULOM AS MATRICULA,
       CE.CDESOCIAL CODCATEG,
       --infoAfastamento
       ASF.DTINISITUFUNC AS dtIniAfast,
       MA.CDESOCIAL AS codMotAfast,
       DECODE(MAANT.CDESOCIAL, NULL,'N', 'S') AS infoMesmoMtv,  
       DECODE(MA.CDESOCIAL, '01','3', NULL) tpAcidTransito,
       ASF.DSOBSALTSITFUNC AS observacao,    
       -- infoAtestado getDadosS2200infoAtestado           
       --fimAfastamento
       ASF.DTFIMSITUFUNC AS dtTermAfast
       
  FROM GPE_ALTESITUFUNC ASF
  JOIN GPE_VINCULOM VM ON VM.NRORG = ASF.NRORG AND ASF.NRVINCULOM = VM.NRVINCULOM
  /*Dados do Empregado - Vínculo*/
  JOIN GPE_VINCULOH VH
    ON VH.NRVINCULOM = VM.NRVINCULOM
   AND VH.NRORG      = VM.NRORG
   AND VH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_VINCULOH
                             WHERE GPE_VINCULOH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                               AND GPE_VINCULOH.NRVINCULOM = VM.NRVINCULOM
                               AND GPE_VINCULOH.NRORG = VM.NRORG)
   /*Categoria Trabalhador*/    
  JOIN GPE_VINCULOEMPREG VE ON VE.NRVINCULOEMPREG = VM.NRVINCULOEMPREG                           
  LEFT JOIN GPE_CATEGTRABESOC CE ON CE.NRCATEGESOC = VE.NRCATEGESOC  
  /*Dados do Empregado - Pessoa*/                               
  JOIN GPE_PESSOA PE
    ON PE.NRPESSOA = VM.NRPESSOA
   AND PE.NRORG    = VM.NRORG
  JOIN GPE_PESSOAH PH
    ON PH.NRPESSOA = PE.NRPESSOA
   AND PH.NRORG    = PE.NRORG
   AND PH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_PESSOAH
                             WHERE GPE_PESSOAH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                               AND GPE_PESSOAH.NRPESSOA = PE.NRPESSOA
                               AND GPE_PESSOAH.NRORG = PE.NRORG)
  JOIN PARCNEGOCIO PN
    ON PN.NRPARCNEGOCIO = PE.NRPARCNEGOCIO
   AND PN.NRORG         = PE.NRORG  
  
  /*Empregador*/
  JOIN ESTRUTURAH EMH ON EMH.NRORG = :P_NRORG
                     AND EMH.NRESTRUTURAM = VH.NRESTRUTLEGAL
                     AND EMH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH
                                               WHERE ESTRUTURAH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                 AND ESTRUTURAH.NRESTRUTURAM = EMH.NRESTRUTURAM
                                                 AND ESTRUTURAH.NRORG = EMH.NRORG)
  JOIN PARCNEGOCIO PAR ON PAR.NRPARCNEGOCIO = EMH.NRPARCNEGOCIO
                      AND PAR.NRORG = EMH.NRORG
  /*Situação Funcional*/
  JOIN GPE_SITUFUNCM SF ON SF.NRSITUFUNCM = ASF.NRSITUFUNCM AND (SF.NRORG = VM.NRORG OR SF.NRORG = 0)
  JOIN GPE_SITUFUNCH SFH ON SFH.NRORG = SF.NRORG
                     AND SFH.NRSITUFUNCM = SF.NRSITUFUNCM
                     AND SFH.DTEFETIVA = (SELECT MAX(DTEFETIVA) FROM GPE_SITUFUNCH
                                               WHERE GPE_SITUFUNCH.DTEFETIVA <= :P_DTMESCOMPETENC
                                                 AND GPE_SITUFUNCH.NRSITUFUNCM = SFH.NRSITUFUNCM
                                                 AND GPE_SITUFUNCH.NRORG = SFH.NRORG)
 JOIN GPE_MOTIVOAFASTA MA ON MA.NRMOTIVOAFASTA = ASF.NRMOTIVOAFASTA AND (MA.NRORG = ASF.NRORG OR MA.NRORG = 0)
 LEFT JOIN GPE_ALTESITUFUNC ASFANT ON ASFANT.NRVINCULOM = VM.NRVINCULOM AND ASFANT.NRORG = VM.NRORG AND 
 ASFANT.DTFIMSITUFUNC BETWEEN ADD_MONTHS(ASF.DTINISITUFUNC, -2) AND ASF.DTINISITUFUNC
 LEFT JOIN GPE_MOTIVOAFASTA MAANT ON MAANT.NRMOTIVOAFASTA = ASFANT.NRMOTIVOAFASTA AND (MAANT.NRORG = ASFANT.NRORG OR MAANT.NRORG = 0)
 AND (MAANT.CDESOCIAL = '01' OR MAANT.CDESOCIAL = '03') AND MAANT.CDESOCIAL = MA.CDESOCIAL
 
 WHERE VM.NRORG = :P_NRORG
   AND ASF.NRALTESITUFUNC = :P_CHAVE
SQL;
        $params = array(
            "P_NRORG" => $this->hcmParameters->getNrorgTrabalho(),
            "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
            "P_NRENVIO" => $nrenvio,
            "P_NRCHAVE" => $nrchave,
            //"P_NRESTRUTURAM" => $nrestruturam
        );
        return $this->connection->fetchAssoc($sql, $params);
    }
    
    public function getDados2230infoAtestado($nrorg, $nrAlteSituFunc) {
        $sql = <<<SQL
SELECT 
--infoAtestado
ASF.CDTABECDI AS codCID ,
ASF.DTFIMSITUFUNC - ASF.DTINISITUFUNC AS qtdDiasAfast,
--emitente
PMH.NMPESSOA AS nmEmit,
PMH.nrconselhoreg AS ideOC,
PMH.NRINSCRCONSREG AS nrOc,
PMH.SGUFCONSREG AS ufOC
FROM GPE_ALTESITUFUNC ASF 
/*Dados Medico Atestado*/
  LEFT JOIN GPE_PESSOA PM
    ON PM.NRPESSOA = ASF.NRPESSOA
   AND PM.NRORG    = ASF.NRORG
  LEFT JOIN GPE_PESSOAH PMH
    ON PMH.NRPESSOA = PM.NRPESSOA
   AND PMH.NRORG    = PM.NRORG
   AND PMH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_PESSOAH
                             WHERE GPE_PESSOAH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                               AND GPE_PESSOAH.NRPESSOA = PM.NRPESSOA
                               AND GPE_PESSOAH.NRORG = PM.NRORG)


WHERE  ASF.NRALTESITUFUNC = :P_CHAVE AND ASF.NRORG = :P_NRORG
SQL;
        $params = array(
            "P_NRORG" => $nrorg,
            "P_NRCHAVE" => $nrAlteSituFunc,
            "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia()
        );
        return $this->connection->fetchAll($sql, $params);
    }
    
    /**
     * @param $nrenvio
     * @param $nrchave
     * @param $nrestruturam
     * @return array    Associative array
     */
    public function getDadosS2240($nrenvio, $nrchave, $nrestruturam) {
        $sql = <<<SQL
SELECT MO.NRMOVIMENTACAO CHAVE,
       'ID'||DECODE(PAR.CDTIPOINSCRICAO,'CNPJ','1','CPF','2','')||RPAD(CASE WHEN EMH.CDNATUJURI IN ('1015','1040','1074','1163') THEN PAR.NRINSCRICAOPARC ELSE SUBSTR(PAR.NRINSCRICAOPARC,1,8) END,14,'0')||TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS')||LPAD(:P_NRENVIO,5,'0') ID,
       --ideEmpregador
       DECODE(PAR.CDTIPOINSCRICAO,'CNPJ','1','CPF','2','') TPINSC,
       CASE WHEN EMH.CDNATUJURI IN ('1015','1040','1074','1163') THEN PAR.NRINSCRICAOPARC ELSE SUBSTR(PAR.NRINSCRICAOPARC,1,8) END NRINSC,    
       --ideVinculo
       REPLACE(REPLACE(PH.NRCPFPESSOA, '.'), '-') AS CPFTRAB,       
       PH.NRPISPASEPPES AS NISTRAB,
       VM.NRVINCULOM AS MATRICULA,
       --infoExpRisco
       --iniExpRisco
       MO.DTINIMOVIMENT AS dtIniCondicao,
       --getDadosS2240infoAmb
       --getDadosS2240fatRisco
       --getDadosS2240epc
       --getDadosS2240epi
       --respReg
       EH.DTINIRESAMB AS dtIni,
       EH.DTFIMRESAMB AS dtFim,   
       PARAMB.NRINSCRICAOPARC AS nisResp,       
       PHAMB.NRINSCRCONSREG AS nrOc,
       PHAMB.SGUFCONSREG AS ufOC       
  FROM GPE_MOVIMENTACAO MO    
  JOIN GPE_VINCULOM VM ON VM.NRVINCULOM = MO.NRVINCULOM AND MO.NRORG = VM.NRORG
  /*Dados do Empregado - Vínculo*/
  JOIN GPE_VINCULOH VH
    ON VH.NRVINCULOM = VM.NRVINCULOM
   AND VH.NRORG      = VM.NRORG
   AND VH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_VINCULOH
                             WHERE GPE_VINCULOH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                               AND GPE_VINCULOH.NRVINCULOM = VM.NRVINCULOM
                               AND GPE_VINCULOH.NRORG = VM.NRORG)
  /*Dados do Empregado - Pessoa*/                               
  JOIN GPE_PESSOA PE
    ON PE.NRPESSOA = VM.NRPESSOA
   AND PE.NRORG    = VM.NRORG
  JOIN GPE_PESSOAH PH
    ON PH.NRPESSOA = PE.NRPESSOA
   AND PH.NRORG    = PE.NRORG
   AND PH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_PESSOAH
                             WHERE GPE_PESSOAH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                               AND GPE_PESSOAH.NRPESSOA = PE.NRPESSOA
                               AND GPE_PESSOAH.NRORG = PE.NRORG)
  /*Dados do Empregado - Estrutura Movimentada*/
  JOIN ESTRUTURAH EH ON EH.NRORG = :P_NRORG
                     AND EH.NRESTRUTURAM = MO.NRESTRUTURAM
                     AND EH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH
                                               WHERE ESTRUTURAH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                 AND ESTRUTURAH.NRESTRUTURAM = EH.NRESTRUTURAM
                                                 AND ESTRUTURAH.NRORG = EH.NRORG)                               
  JOIN PARCNEGOCIO PN
    ON PN.NRPARCNEGOCIO = PE.NRPARCNEGOCIO
   AND PN.NRORG         = PE.NRORG                               
  /*Empregador*/
  JOIN ESTRUTURAH EMH ON EMH.NRORG = :P_NRORG
                     AND EMH.NRESTRUTURAM = :P_NRESTRUTURAM
                     AND EMH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH
                                               WHERE ESTRUTURAH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                 AND ESTRUTURAH.NRESTRUTURAM = EMH.NRESTRUTURAM
                                                 AND ESTRUTURAH.NRORG = EMH.NRORG)
  JOIN PARCNEGOCIO PAR ON PAR.NRPARCNEGOCIO = EMH.NRPARCNEGOCIO
                      AND PAR.NRORG = EMH.NRORG
  /*Responsavel Ambiente*/ 
  LEFT JOIN PARCNEGOCIO PARAMB ON PARAMB.NRPARCNEGOCIO = EH.NRPARCREGAMB
                      AND PARAMB.NRORG = EH.NRORG
  LEFT JOIN GPE_PESSOA PAMB
    ON PAMB.NRPARCNEGOCIO = PARAMB.NRPARCNEGOCIO
   AND PAMB.NRORG    = VM.NRORG
  LEFT JOIN GPE_PESSOAH PHAMB
    ON PHAMB.NRPESSOA = PAMB.NRPESSOA
   AND PHAMB.NRORG    = PE.NRORG
   AND PHAMB.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_PESSOAH
                             WHERE GPE_PESSOAH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                               AND GPE_PESSOAH.NRPESSOA = PHAMB.NRPESSOA
                               AND GPE_PESSOAH.NRORG = PHAMB.NRORG)                   
  
 WHERE MO.NRORG = :P_NRORG
   AND MO.NRMOVIMENTACAO = :P_NRCHAVE
SQL;
        $params = array(
            "P_NRORG" => $this->hcmParameters->getNrorgTrabalho(),
            "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
            "P_NRENVIO" => $nrenvio,
            "P_NRCHAVE" => $nrchave,
            "P_NRESTRUTURAM" => $nrestruturam
        );
        return $this->connection->fetchAssoc($sql, $params);
    }
    
    public function getDadosS2240infoAmb($nrorg, $nrvinculom, $nrestruturam) {
        $sql = <<<SQL
SELECT EM.NRESTRUTURAM AS codAmb,
       --infoAtiv
       PP.NMPERFILPPP
FROM ESTRUTURAM EM
JOIN ESTRUTURAH EH ON EH.NRORG = :P_NRORG
                     AND EH.NRESTRUTURAM = EM.NRESTRUTURAM
                     AND EH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH
                                               WHERE ESTRUTURAH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                 AND ESTRUTURAH.NRESTRUTURAM = EH.NRESTRUTURAM
                                                 AND ESTRUTURAH.NRORG = EH.NRORG)
/*Dados do Empregado - Vínculo*/
  JOIN GPE_VINCULOM VM ON VM.NRVINCULOM = :P_NRVINCULOM AND VM.NRORG = EM.NRORG  
  JOIN GPE_VINCULOH VH
    ON VH.NRVINCULOM = VM.NRVINCULOM
   AND VH.NRORG      = VM.NRORG
   AND VH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_VINCULOH
                             WHERE GPE_VINCULOH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                               AND GPE_VINCULOH.NRVINCULOM = VM.NRVINCULOM
                               AND GPE_VINCULOH.NRORG = VM.NRORG)
 /*Dados do Empregado - Ocupação*/                              
 JOIN GPE_OCUPACAOM OM ON OM.NROCUPACAOM = VH.NRCARGO AND OM.NRORG = EM.NRORG  
  JOIN GPE_OCUPACAOH OH
    ON OH.NROCUPACAOM = OM.NROCUPACAOM
   AND OH.NRORG      = OM.NRORG
   AND OH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_OCUPACAOH
                             WHERE GPE_OCUPACAOH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                               AND GPE_OCUPACAOH.NROCUPACAOM = OM.NROCUPACAOM
                               AND GPE_OCUPACAOH.NRORG = OM.NRORG)    
 LEFT JOIN SST_RELACOCUPAPPP ROP ON ROP.NROCUPACAOM = OM.NROCUPACAOM AND OM.NRORG = ROP.NRORG                                
 LEFT JOIN SST_PERFILPPP PP ON PP.NRPERFILPPP = ROP.NRPERFILPPP AND PP.NRORG = ROP.NRORG
WHERE EM.NRORG = :P_NRORG 
AND EM.NRESTRUTURAM = :P_NRESTRUTURAM
SQL;
        $params = array(
            "P_NRORG" => $nrorg,
            "P_NRVINCULOM" => $nrvinculom,
            "P_NRESTRUTURAM" => $nrestruturam,
            "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia()
        );
        return $this->connection->fetchAll($sql, $params);
    }
    
    public function getDadosS2240fatRisco($nrorg, $nrestruturaMovimentada) {
        $sql = <<<SQL
SELECT RA.CDESOCIAL AS codFatRis,
          FR.DSINTENSIDADE AS intConc,
          FR.DSTECNICA AS tecMedicao,
          --epcEpi
          DECODE(RC.NRRISCOEPC, NULL, 1, 2) utilizEPC, 
          DECODE(RE.NRRISCOEPI, NULL, 1, 2) utilizEPI,
          FR.NRFATORRISCO
FROM SST_RELESTRUTRISCO RER
JOIN SST_FATORRISCO FR
ON FR.NRFATORRISCO = RER.NRFATORRISCO
AND FR.NRORG       = RER.NRORG
JOIN GPE_FATRISCAMB RA
ON RA.NRFATRISCAMB     = FR.NRFATRISCAMB
AND (RA.NRORG          = FR.NRORG
OR RA.NRORG            = 0)
LEFT JOIN SST_RISCOEPI RE ON RE.NRFATORRISCO = FR.NRFATORRISCO AND RE.NRORG = FR.NRORG 
LEFT JOIN SST_RISCOEPC RC ON RC.NRFATORRISCO = FR.NRFATORRISCO AND RC.NRORG = FR.NRORG
WHERE RER.NRESTRUTURAM = :P_NRESTRUTURAM
AND RER.NRORG          = :P_NRORG
SQL;
        $params = array(
            "P_NRORG" => $nrorg,
            "P_NRESTRUTURAM" => $nrestruturaMovimentada
        );
        return $this->connection->fetchAll($sql, $params);
    }
    
    public function getDadosS2240epc($nrorg, $nrfatorrisco) {
        $sql = <<<SQL
SELECT NMEPC AS dscEpc,
IDEPCEFICAZ AS eficEpc 
FROM SST_RISCOEPC
WHERE NRFATORRISCO = :P_NRFATORRISCO
AND NRORG = :P_NRORG
SQL;
        $params = array(
            "P_NRORG" => $nrorg,
            "P_NRFATORRISCO" => $nrfatorrisco
        );
        return $this->connection->fetchAll($sql, $params);
    }
    
    public function getDadosS2240epi($nrorg, $nrfatorrisco, $nrvinculom) {
        $sql = <<<SQL
SELECT E.CERTIAPROV                         AS caEPI,
  RE.IDEPIEFICAZ                            AS eficEpi,
  DECODE(E.NRTIPOMEDIDAEPI, NULL, 'N', 'S') AS medProtecao, 
  HE.IDCONDFUNCIO AS condFuncto, 
  HE.IDPRAZOVALID AS przValid, 
  HE.IDPERIODICTROCA AS periodicTroca, 
  HE.IDHIGIENIZACAO AS higienizacao
FROM SST_RISCOEPI RE
JOIN SST_EPI E
ON E.NRORG  = RE.NRORG
AND E.NREPI = RE.NREPI
LEFT JOIN SST_HISTORICOEPI HE
ON HE.NREPI  = E.NREPI
AND HE.NRORG = RE.NRORG
AND HE.NRVINCULOM = :P_NRVINCULOM
WHERE RE.NRFATORRISCO = :P_NRFATORRISCO
AND RE.NRORG          = :P_NRORG
SQL;
        $params = array(
            "P_NRORG" => $nrorg,
            "P_NRFATORRISCO" => $nrfatorrisco,
            "P_NRVINCULOM" => $nrvinculom
        );
        return $this->connection->fetchAll($sql, $params);
    }
    
    /**
     * @param $nrenvio
     * @param $nrchave
     * @param $nrestruturam
     * @return array    Associative array
     */
    public function getDadosS2241($nrenvio, $nrchave, $nrestruturam) {
        $sql = <<<SQL
SELECT MO.NRMOVIMENTACAO CHAVE,
       'ID'||DECODE(PAR.CDTIPOINSCRICAO,'CNPJ','1','CPF','2','')||RPAD(CASE WHEN EMH.CDNATUJURI IN ('1015','1040','1074','1163') THEN PAR.NRINSCRICAOPARC ELSE SUBSTR(PAR.NRINSCRICAOPARC,1,8) END,14,'0')||TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS')||LPAD(:P_NRENVIO,5,'0') ID,
       --ideEmpregador
       DECODE(PAR.CDTIPOINSCRICAO,'CNPJ','1','CPF','2','') TPINSC,
       CASE WHEN EMH.CDNATUJURI IN ('1015','1040','1074','1163') THEN PAR.NRINSCRICAOPARC ELSE SUBSTR(PAR.NRINSCRICAOPARC,1,8) END NRINSC,    
       --ideVinculo
       REPLACE(REPLACE(PH.NRCPFPESSOA, '.'), '-') AS CPFTRAB,  
       PH.NRPISPASEPPES AS nisTrab,
       VM.CDMATRICULA AS matricula,       
       --insalPeric
       --iniInsalPeric 
       CASE
         WHEN FR.IDGERAPERIC = 'S' OR FR.IDGERAINSAL = 'S' THEN
           MO.DTINIMOVIMENT
        END AS dtIniCondicao,
       --aposentEsp       
       DECODE(FR.IDGERAAPOSESPEC, 'S',  MO.DTINIMOVIMENT) AS iniAposentEsp_dtIniCondicao
  FROM GPE_MOVIMENTACAO MO    
  JOIN GPE_VINCULOM VM ON VM.NRVINCULOM = MO.NRVINCULOM AND MO.NRORG = VM.NRORG
  /*Dados do Empregado - Vínculo*/
  JOIN GPE_VINCULOH VH
    ON VH.NRVINCULOM = VM.NRVINCULOM
   AND VH.NRORG      = VM.NRORG
   AND VH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_VINCULOH
                             WHERE GPE_VINCULOH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                               AND GPE_VINCULOH.NRVINCULOM = VM.NRVINCULOM
                               AND GPE_VINCULOH.NRORG = VM.NRORG)
  /*Dados do Empregado - Pessoa*/                               
  JOIN GPE_PESSOA PE
    ON PE.NRPESSOA = VM.NRPESSOA
   AND PE.NRORG    = VM.NRORG
  JOIN GPE_PESSOAH PH
    ON PH.NRPESSOA = PE.NRPESSOA
   AND PH.NRORG    = PE.NRORG
   AND PH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_PESSOAH
                             WHERE GPE_PESSOAH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                               AND GPE_PESSOAH.NRPESSOA = PE.NRPESSOA
                               AND GPE_PESSOAH.NRORG = PE.NRORG)
  JOIN PARCNEGOCIO PN
    ON PN.NRPARCNEGOCIO = PE.NRPARCNEGOCIO
   AND PN.NRORG         = PE.NRORG                               
  /*Empregador*/
  JOIN ESTRUTURAH EMH ON EMH.NRORG = :P_NRORG
                     AND EMH.NRESTRUTURAM = :P_NRESTRUTURAM
                     AND EMH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH
                                               WHERE ESTRUTURAH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                 AND ESTRUTURAH.NRESTRUTURAM = EMH.NRESTRUTURAM
                                                 AND ESTRUTURAH.NRORG = EMH.NRORG)
  JOIN PARCNEGOCIO PAR ON PAR.NRPARCNEGOCIO = EMH.NRPARCNEGOCIO
                      AND PAR.NRORG = EMH.NRORG
  /*Estrutura Movimentada*/
JOIN ESTRUTURAH EH ON EH.NRORG = :P_NRORG
                     AND EH.NRESTRUTURAM = VH.NRESTRUTGEREN
                     AND EH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH
                                               WHERE ESTRUTURAH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                 AND ESTRUTURAH.NRESTRUTURAM = EH.NRESTRUTURAM
                                                 AND ESTRUTURAH.NRORG = EH.NRORG)
JOIN SST_RELESTRUTRISCO RER ON RER.NRESTRUTURAM = EH.NRESTRUTURAM AND RER.NRORG = EH.NRORG 
JOIN SST_FATORRISCO FR
ON FR.NRFATORRISCO = RER.NRFATORRISCO
AND FR.NRORG       = RER.NRORG
AND (FR.IDGERAINSAL = 'S' OR FR.IDGERAPERIC = 'S' OR FR.IDGERAAPOSESPEC = 'S')                      
 WHERE VM.NRORG = :P_NRORG
   AND MO.NRMOVIMENTACAO = :P_NRCHAVE
SQL;
        $params = array(
            "P_NRORG" => $this->hcmParameters->getNrorgTrabalho(),
            "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
            "P_NRENVIO" => $nrenvio,
            "P_NRCHAVE" => $nrchave,
            "P_NRESTRUTURAM" => $nrestruturam
        );
        return $this->connection->fetchAssoc($sql, $params);
    }
    
    public function getDadosS2241infoAmb($nrorg, $nrvinculom, $nrestruturam) {
        $sql = <<<SQL
SELECT EM.NRESTRUTURAM AS codAmb      
FROM ESTRUTURAM EM
JOIN ESTRUTURAH EH ON EH.NRORG = :P_NRORG
                     AND EH.NRESTRUTURAM = EM.NRESTRUTURAM
                     AND EH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH
                                               WHERE ESTRUTURAH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                 AND ESTRUTURAH.NRESTRUTURAM = EH.NRESTRUTURAM
                                                 AND ESTRUTURAH.NRORG = EH.NRORG)
WHERE EM.NRORG = :P_NRORG 
AND EM.NRESTRUTURAM = :P_NRESTRUTURAM
SQL;
        $params = array(
            "P_NRORG" => $nrorg,
            "P_NRESTRUTURAM" => $nrestruturam,
            "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia()
        );
        return $this->connection->fetchAll($sql, $params);
    }
    
    public function getDadosS2241fatRisco($nrorg, $nrestruturaMovimentada) {
        $sql = <<<SQL
SELECT RA.CDESOCIAL AS codFatRis
FROM SST_RELESTRUTRISCO RER
JOIN SST_FATORRISCO FR
ON FR.NRFATORRISCO = RER.NRFATORRISCO
AND FR.NRORG       = RER.NRORG
JOIN GPE_FATRISCAMB RA
ON RA.NRFATRISCAMB     = FR.NRFATRISCAMB
AND (RA.NRORG          = FR.NRORG
OR RA.NRORG            = 0)
WHERE RER.NRESTRUTURAM = :P_NRESTRUTURAM
AND RER.NRORG          = :P_NRORG
SQL;
        $params = array(
            "P_NRORG" => $nrorg,
            "P_NRESTRUTURAM" => $nrestruturaMovimentada
        );
        return $this->connection->fetchAll($sql, $params);
    }
    
    /**
     * @param $nrenvio
     * @param $nrchave
     * @param $nrestruturam
     * @return array    Associative array
     */
    public function getDadosS2250($nrenvio, $nrchave, $nrestruturam) {
        $sql = <<<SQL
SELECT VM.NRVINCULOM CHAVE,
       'ID'||DECODE(PAR.CDTIPOINSCRICAO,'CNPJ','1','CPF','2','')||RPAD(CASE WHEN ET.CDNATUJURI IN ('1015','1040','1074','1163') THEN PAR.NRINSCRICAOPARC ELSE SUBSTR(PAR.NRINSCRICAOPARC,1,8) END,14,'0')||TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS')||LPAD(:P_NRENVIO,5,'0') id,
       --ideEmpregador
       DECODE(PAR.CDTIPOINSCRICAO,'CNPJ','1','CPF','2','') tpInsc,
           CASE WHEN ET.CDNATUJURI IN ('1015','1040','1074','1163') THEN PAR.NRINSCRICAOPARC ELSE SUBSTR(PAR.NRINSCRICAOPARC,1,8) END nrInsc,
       --ideVinculo
       REPLACE(REPLACE(PH.NRCPFPESSOA, '.'), '-') AS CPFTRAB,  
       PH.NRPISPASEPPES AS nisTrab,
       VM.CDMATRICULA AS matricula,
       --infoAvPrevio
       VM.DTAVISOPREVIO AS dtAvPrv,
       VM.DTRESCISAOVINC AS dtPrevDeslig,
       TAP.CDESOCIAL AS tpAvPrevio,
       VM.DSOBSRESCISAO AS observacao
       --cancAvPrevio
       
  FROM GPE_VINCULOM VM
  JOIN GPE_VINCULOEMPREG VE ON VE.NRVINCULOEMPREG = VM.NRVINCULOEMPREG
  LEFT JOIN GPE_CATEGTRABESOC CE ON CE.NRCATEGESOC = VE.NRCATEGESOC
  JOIN GPE_VINCULOH VH ON VH.NRVINCULOM = VM.NRVINCULOM
                      AND VH.NRORG = VM.NRORG
                      AND VH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_VINCULOH
                                                WHERE GPE_VINCULOH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                  AND GPE_VINCULOH.NRVINCULOM = VH.NRVINCULOM
                                                  AND GPE_VINCULOH.NRORG = VH.NRORG)
  /*Local de Trabalho*/
  JOIN ESTRUTURAH ET ON ET.NRESTRUTURAM = VH.NRESTRUTGEREN
                    AND ET.NRORG = VH.NRORG
                    AND ET.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH
                                              WHERE ESTRUTURAH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                AND ESTRUTURAH.NRESTRUTURAM = ET.NRESTRUTURAM
                                                AND ESTRUTURAH.NRORG = ET.NRORG)
  JOIN PARCNEGOCIO PN ON PN.NRPARCNEGOCIO = ET.NRPARCNEGOCIO
                     AND PN.NRORG = ET.NRORG
  /*Tipo Demissao*/                   
  JOIN FPA_TPDEMISSAO TD ON VM.NRTPDEMISSAO = TD.NRTPDEMISSAO 
    AND (TD.NRORG = :P_NRORG OR TD.NRORG = 0)                   
  JOIN GPE_PESSOA PE ON VM.NRPESSOA = PE.NRPESSOA
                    AND VM.NRORG    = PE.NRORG
  JOIN GPE_PESSOAH PH ON PE.NRPESSOA = PH.NRPESSOA
                     AND PE.NRORG    = PH.NRORG
                     AND PH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_PESSOAH
                                               WHERE GPE_PESSOAH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                 AND GPE_PESSOAH.NRPESSOA = PH.NRPESSOA
                                                 AND GPE_PESSOAH.NRORG = PH.NRORG)  
  LEFT JOIN GPE_CLASSESTRANG CT ON CT.NRCLASSESTRANG = PH.NRCLASSESTRANG 
  JOIN PARCNEGOCIO PAR ON PAR.NRPARCNEGOCIO = ET.NRPARCNEGOCIO
                      AND PAR.NRORG = ET.NRORG
  LEFT JOIN GPE_TIPOAVISOPRE TAP ON TAP.NRTPAVIPRE = VM.NRTPAVIPRE                      
 WHERE VM.NRORG = :P_NRORG
   AND VH.NRESTRUTLEGAL = :P_NRESTRUTURAM
   AND (VM.DTRESCISAOVINC IS NULL OR VM.DTRESCISAOVINC >= :P_DTMESCOMPETENC)
   AND VM.NRVINCULOM = :P_NRCHAVE
SQL;
        $params = array(
            "P_NRORG" => $this->hcmParameters->getNrorgTrabalho(),
            "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
            "P_NRENVIO" => $nrenvio,
            "P_NRCHAVE" => $nrchave,
            "P_NRESTRUTURAM" => $nrestruturam
        );
        return $this->connection->fetchAssoc($sql, $params);
    }
    
     /**
     * @param $nrenvio
     * @param $nrchave
     * @param $nrestruturam
     * @return array    Associative array
     */
    public function getDadosS2298($nrenvio, $nrchave, $nrestruturam) {
        $sql = <<<SQL
SELECT VM.NRVINCULOM CHAVE,
       'ID'||DECODE(PAR.CDTIPOINSCRICAO,'CNPJ','1','CPF','2','')||RPAD(CASE WHEN EMH.CDNATUJURI IN ('1015','1040','1074','1163') THEN PAR.NRINSCRICAOPARC ELSE SUBSTR(PAR.NRINSCRICAOPARC,1,8) END,14,'0')||TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS')||LPAD(:P_NRENVIO,5,'0') ID,
       --ideEmpregador
       DECODE(PAR.CDTIPOINSCRICAO,'CNPJ','1','CPF','2','') TPINSC,
       CASE WHEN EMH.CDNATUJURI IN ('1015','1040','1074','1163') THEN PAR.NRINSCRICAOPARC ELSE SUBSTR(PAR.NRINSCRICAOPARC,1,8) END NRINSC,    
       --ideVinculo
       REPLACE(REPLACE(PH.NRCPFPESSOA, '.'), '-') AS CPFTRAB,  
       PH.NRPISPASEPPES AS nisTrab,
       VM.CDMATRICULA AS matricula, 
       --infoReintegr
       VM.IDTPREINTEGRACAO AS tpReint,
       VM.NRPROCJUD AS nrProcJud,
       VM.NRLEIANISTIA AS nrLeiAnistia,       
       VM.DTRETORNO AS dtEfetRetorno,
       VM.DTEFEITOFINANCEIRO AS dtEfeito,
       VM.IDPAGTOJUIZO AS indPagtoJuizo    
  FROM GPE_VINCULOM VM
  /*Dados do Empregado - Vínculo*/
  JOIN GPE_VINCULOH VH
    ON VH.NRVINCULOM = VM.NRVINCULOM
   AND VH.NRORG      = VM.NRORG
   AND VH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_VINCULOH
                             WHERE GPE_VINCULOH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                               AND GPE_VINCULOH.NRVINCULOM = VM.NRVINCULOM
                               AND GPE_VINCULOH.NRORG = VM.NRORG)
  /*Dados do Empregado - Pessoa*/                               
  JOIN GPE_PESSOA PE
    ON PE.NRPESSOA = VM.NRPESSOA
   AND PE.NRORG    = VM.NRORG
  JOIN GPE_PESSOAH PH
    ON PH.NRPESSOA = PE.NRPESSOA
   AND PH.NRORG    = PE.NRORG
   AND PH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_PESSOAH
                             WHERE GPE_PESSOAH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                               AND GPE_PESSOAH.NRPESSOA = PE.NRPESSOA
                               AND GPE_PESSOAH.NRORG = PE.NRORG)
  JOIN PARCNEGOCIO PN
    ON PN.NRPARCNEGOCIO = PE.NRPARCNEGOCIO
   AND PN.NRORG         = PE.NRORG                               
  /*Empregador*/
  JOIN ESTRUTURAH EMH ON EMH.NRORG = :P_NRORG
                     AND EMH.NRESTRUTURAM = :P_NRESTRUTURAM
                     AND EMH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH
                                               WHERE ESTRUTURAH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                 AND ESTRUTURAH.NRESTRUTURAM = EMH.NRESTRUTURAM
                                                 AND ESTRUTURAH.NRORG = EMH.NRORG)
  JOIN PARCNEGOCIO PAR ON PAR.NRPARCNEGOCIO = EMH.NRPARCNEGOCIO
                      AND PAR.NRORG = EMH.NRORG
 WHERE VM.NRORG = :P_NRORG
   AND VM.NRVINCULOM = :P_NRCHAVE
SQL;
        $params = array(
            "P_NRORG" => $this->hcmParameters->getNrorgTrabalho(),
            "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
            "P_NRENVIO" => $nrenvio,
            "P_NRCHAVE" => $nrchave,
            "P_NRESTRUTURAM" => $nrestruturam
        );
        return $this->connection->fetchAssoc($sql, $params);
    }
    
     /**
     * @param $nrenvio
     * @param $nrchave
     * @param $nrestruturam
     * @return array    Associative array
     */
    public function getDadosS2299($nrenvio, $nrchave, $nrestruturam) {
        $sql = <<<SQL
SELECT VM.NRVINCULOM CHAVE,
       'ID'||DECODE(PAR.CDTIPOINSCRICAO,'CNPJ','1','CPF','2','')||RPAD(CASE WHEN EMH.CDNATUJURI IN ('1015','1040','1074','1163') THEN PAR.NRINSCRICAOPARC ELSE SUBSTR(PAR.NRINSCRICAOPARC,1,8) END,14,'0')||TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS')||LPAD(:P_NRENVIO,5,'0') ID,
       --ideEmpregador
       DECODE(PAR.CDTIPOINSCRICAO,'CNPJ','1','CPF','2','') TPINSC,
       CASE WHEN EMH.CDNATUJURI IN ('1015','1040','1074','1163') THEN PAR.NRINSCRICAOPARC ELSE SUBSTR(PAR.NRINSCRICAOPARC,1,8) END NRINSC,    
       --ideVinculo
       REPLACE(REPLACE(PH.NRCPFPESSOA, '.'), '-') AS CPFTRAB,  
       PH.NRPISPASEPPES AS nisTrab,
       VM.CDMATRICULA AS matricula,
       --infoDeslig
       TD.CDESOCIAL AS mtvDeslig,
       TO_CHAR(VM.DTRESCISAOVINC,'YYYY-MM-DD') AS dtDeslig,
       TO_CHAR(VM.DTAVISOPREVIO,'YYYY-MM-DD') AS ProjFimAPI,
       DECODE(VM.NRTPAVIPRE, null, 'N', 'S') indPagtoAPI,       
       DECODE(ITC.NREVENTOM, null, 0, 3) AS pensAlim,
       EH.VRPERCENTUALEVENTO AS percAliment,
       ITC.VRREFFOLHA AS vrAlim,
       PH.NRCERTOBITO AS nrCertObito,
       VM.NRPROCJUD AS nrProcTrab,
       DECODE(VM.NRTPAVIPRE, 3, 4, 0) indCumprParc,
       VM.DSOBSRESCISAO AS observacao,      
       --sucessaoVinc
       null cnpjSucessora,
       null cpfSubstituto,
       null dtNascto,
       --verbasResc
       --dmDev getDadosS2399dmDev       
       --ideEstabLot getDadosS2399ideEstabLot       
       --detVerbas getDadosS2399detVerbas       
       --detOper getDadosS2399detOper       
       --detPlano getDadosS2399detPlano       
       --procJudTrab getDadosS2399procJudTrab     
       --infoMV
       --getDadosS2399remunOutrEmpr
       1 AS indMV,
       null dtFimQuar           
  FROM GPE_VINCULOM VM
  /*Dados do Empregado - Vínculo*/
  JOIN GPE_VINCULOH VH
    ON VH.NRVINCULOM = VM.NRVINCULOM
   AND VH.NRORG      = VM.NRORG
   AND VH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_VINCULOH
                             WHERE GPE_VINCULOH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                               AND GPE_VINCULOH.NRVINCULOM = VM.NRVINCULOM
                               AND GPE_VINCULOH.NRORG = VM.NRORG)
  /*Dados do Empregado - Pessoa*/                               
  JOIN GPE_PESSOA PE
    ON PE.NRPESSOA = VM.NRPESSOA
   AND PE.NRORG    = VM.NRORG
  JOIN GPE_PESSOAH PH
    ON PH.NRPESSOA = PE.NRPESSOA
   AND PH.NRORG    = PE.NRORG
   AND PH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_PESSOAH
                             WHERE GPE_PESSOAH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                               AND GPE_PESSOAH.NRPESSOA = PE.NRPESSOA
                               AND GPE_PESSOAH.NRORG = PE.NRORG)
  JOIN PARCNEGOCIO PN
    ON PN.NRPARCNEGOCIO = PE.NRPARCNEGOCIO
   AND PN.NRORG         = PE.NRORG                               
  /*Empregador*/
  JOIN ESTRUTURAH EMH ON EMH.NRORG = :P_NRORG
                     AND EMH.NRESTRUTURAM = :P_NRESTRUTURAM
                     AND EMH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH
                                               WHERE ESTRUTURAH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                 AND ESTRUTURAH.NRESTRUTURAM = EMH.NRESTRUTURAM
                                                 AND ESTRUTURAH.NRORG = EMH.NRORG)
  /*Demissao*/
  JOIN FPA_TPDEMISSAO TD ON VM.NRTPDEMISSAO = TD.NRTPDEMISSAO 
    AND (TD.NRORG = :P_NRORG OR TD.NRORG = 0)      
  JOIN PARCNEGOCIO PAR ON PAR.NRPARCNEGOCIO = EMH.NRPARCNEGOCIO
                      AND PAR.NRORG = EMH.NRORG
  /*Pensão*/  
  LEFT JOIN FPA_ITECALCFOLHA ITC
    ON ITC.NRCALCULOFOLHA = 
    (SELECT ITC.NRCALCULOFOLHA
    FROM FPA_ITECALCFOLHA ITC
    WHERE NRVINCULOM = :P_NRCHAVE
            AND NRORG = :P_NRORG
            AND ITC.NREVENTOM = '3050'
            AND ITC.DTOCORRENCIA = 
        (SELECT MAX(ITCH.DTOCORRENCIA)
        FROM FPA_ITECALCFOLHA ITCH
        WHERE ITCH.NRORG = ITC.NRORG
                AND ITCH.NRVINCULOM = ITC.NRVINCULOM
                AND ITCH.NREVENTOM = '3050'
                AND ITCH.DTOCORRENCIA <= :P_DTMESCOMPETENC))
            AND ITC.NRVINCULOM = VM.NRVINCULOM
        AND ITC.NREVENTOM IN 
    (SELECT NREVENTOM
    FROM FPA_INCIDEVENTO IE
    WHERE IE.NRORG = VM.NRORG
            AND IE.NRTIPOINCIDE = 132) 
   LEFT JOIN FPA_EVENTOM EM ON EM.NREVENTOM = ITC.NREVENTOM 
   AND (EM.NRORG = :P_NRORG OR EM.NRORG = 0) 
   LEFT JOIN FPA_EVENTOH EH
    ON EH.NREVENTOM        = EM.NREVENTOM
      AND (EH.NRORG = :P_NRORG OR EH.NRORG = 0)
      AND EH.DTMESCOMPETENC  = (SELECT MAX(EHH.DTMESCOMPETENC) FROM FPA_EVENTOH EHH
                                                         WHERE EHH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                           AND EHH.NREVENTOM = EH.NREVENTOM
                                                           AND EHH.NRORG = EH.NRORG)
                                                           
                                                           
 WHERE VM.NRORG = :P_NRORG
 AND VM.NRVINCULOM = :P_NRCHAVE
SQL;
        $params = array(
            "P_NRORG" => $this->hcmParameters->getNrorgTrabalho(),
            "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
            "P_NRENVIO" => $nrenvio,
            "P_NRCHAVE" => $nrchave,
            "P_NRESTRUTURAM" => $nrestruturam
        );
        return $this->connection->fetchAssoc($sql, $params);
    }
    
    public function getDadosS2299dmDev($nrorg, $dtrescisao, $nrvinculom) {
        $sql = <<<SQL
SELECT ITC.NRCALCULOFOLHA AS ideDmDev
FROM FPA_ITECALCFOLHA ITC
WHERE ITC.NRVINCULOM     = :P_CHAVE
AND ITC.NRORG = :P_NRORG and
ITC.NREVENTOM = '3050'
AND ITC.DTOCORRENCIA =
  (SELECT MAX(ITCH.DTOCORRENCIA)
  FROM FPA_ITECALCFOLHA ITCH
  WHERE ITCH.NRORG       = ITC.NRORG
  AND ITCH.NRVINCULOM = ITC.NRVINCULOM
  AND
  ITCH.NREVENTOM = '3050' AND ITCH.DTOCORRENCIA <= :P_DTRESCISAOVINC)
SQL;
        $params = array(
            "P_NRORG" => $nrorg,
            "P_DTRESCISAOVINC" => $dtrescisao,
            "P_CHAVE" => $nrvinculom
        );
        return $this->connection->fetchAll($sql, $params);
    }
    
    public function getDadosS2299ideEstabLot($nrorg, $nrestruturaMovimentada) {
        $sql = <<<SQL
SELECT 
NVL(DECODE(PNSUP.CDTIPOINSCRICAO,'CNPJ','1','CPF','2',''), 
DECODE(PN.CDTIPOINSCRICAO,'CNPJ','1','CPF','2','')) AS tpInsc,
CASE WHEN EH.CDNATUJURI IN ('1015','1040','1074','1163') THEN NVL(PNSUP.NRINSCRICAOPARC, PN.NRINSCRICAOPARC) ELSE NVL(SUBSTR(PNSUP.NRINSCRICAOPARC,1,8),  SUBSTR(PN.NRINSCRICAOPARC,1,8)) END nrInsc,
NVL(EMSUP.NRESTRUTURAM, EM.NRESTRUTURAM) AS codLotacao,
1 AS grauExp,
DECODE(NVL(CTSUP.CDESOCIAL,CT.CDESOCIAL),'01','1','02','2','03','3','') AS indSimples

FROM ESTRUTURAM EM
JOIN ESTRUTURAH EH ON EH.NRESTRUTURAM = EM.NRESTRUTURAM
                    AND EH.NRORG = EM.NRORG
                    AND EH.DTMESCOMPETENC = (SELECT MAX(EHH.DTMESCOMPETENC) FROM ESTRUTURAH EHH
                                              WHERE EHH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                AND EHH.NRESTRUTURAM = EH.NRESTRUTURAM
                                                AND EHH.NRORG = EH.NRORG)
LEFT JOIN CLASSTRIBUT CT 
ON CT.NRCLASSTRIBUT = EH.NRCLASSTRIBUT                                                
JOIN PARCNEGOCIO PN ON 
PN.NRORG = EM.NRORG AND 
PN.NRPARCNEGOCIO = EM.NRPARCNEGOCIO
JOIN HIERARQUIAORG HO
ON HO.NRESTRUTURAMREL = EM.NRESTRUTURAM
AND HO.NRORG          = EM.NRORG
LEFT JOIN ESTRUTURAM EMSUP
ON EMSUP.NRESTRUTURAM     = HO.NRESTRUTURAMSUP
AND EMSUP.NRORG           = EM.NRORG
AND EMSUP.NRTIPOESTRUTURA = '4'
LEFT JOIN ESTRUTURAH EHSUP ON EHSUP.NRESTRUTURAM = EM.NRESTRUTURAM
                    AND EHSUP.NRORG = EM.NRORG
                    AND EHSUP.DTMESCOMPETENC = (SELECT MAX(EHHSUP.DTMESCOMPETENC) FROM ESTRUTURAH EHHSUP
                                              WHERE EHHSUP.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                AND EHHSUP.NRESTRUTURAM = EH.NRESTRUTURAM
                                                AND EHHSUP.NRORG = EH.NRORG)
LEFT JOIN CLASSTRIBUT CTSUP 
ON CTSUP.NRCLASSTRIBUT = EHSUP.NRCLASSTRIBUT
LEFT JOIN PARCNEGOCIO PNSUP
ON PNSUP.NRPARCNEGOCIO = EMSUP.NRPARCNEGOCIO 
AND PNSUP.NRORG = EMSUP.NRORG
WHERE EM.NRORG            = :P_NRORG
AND EM.NRESTRUTURAM       = :P_NRESTRUTURAM
SQL;
        $params = array(
            "P_NRORG" => $nrorg,
            "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
            "P_NRESTRUTURAM" => $nrestruturaMovimentada
        );
        return $this->connection->fetchAll($sql, $params);
    }
    
    public function getDadosS2299detVerbas($nrorg, $nrvinculom, $nrcalculofolha) {
        $sql = <<<SQL
SELECT ITC.NREVENTOM AS codRubr,
  CF.NRTIPOMOVIMENT  AS ideTabRubr,
  ITC.VRREFFOLHA     AS qtdRubr,
  EH.VRPERCENTUALEVENTO  AS fatorRubr,
  DECODE(ITC.VRREFFOLHA,'0', '', TO_CHAR(ITC.VREVENTOFOLHA / ITC.VRREFFOLHA, '9G999D99')) AS vrUnit,
  ITC.VREVENTOFOLHA AS vrRubr
FROM FPA_ITECALCFOLHA ITC
JOIN FPA_CALCULOFOLHA CF
ON ITC.NRCALCULOFOLHA = CF.NRCALCULOFOLHA
AND CF.NRORG          = ITC.NRORG
JOIN FPA_EVENTOH EH
ON EH.NREVENTOM        = ITC.NREVENTOM
AND (EH.NRORG = :P_NRORG OR EH.NRORG = 0)
AND EH.DTMESCOMPETENC  = (SELECT MAX(EHH.DTMESCOMPETENC) FROM FPA_EVENTOH EHH
                                                         WHERE EHH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                           AND EHH.NREVENTOM = EH.NREVENTOM
                                                           AND EHH.NRORG = EH.NRORG)
WHERE ITC.NRVINCULOM   = :P_CHAVE
AND ITC.NRORG          = :P_NRORG
AND ITC.NRCALCULOFOLHA = :P_NRCALCULOFOLHA
SQL;
        $params = array(
            "P_NRORG" => $nrorg,
            "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
            "P_CHAVE" => $nrvinculom,
            "P_NRCALCULOFOLHA" => $nrcalculofolha
        );
        return $this->connection->fetchAll($sql, $params);
    }
    
    public function getDadosS2299detOper($nrorg, $nrcalculofolha, $nrvinculom) {
        $sql = <<<SQL
SELECT ET.CDCNPJESTRUT AS cnpjOper,
         et.CDFEDERALESTRUT AS regANS,
         ITC.VREVENTOFOLHA AS vrPgTit
FROM FPA_ITECALCFOLHA ITC
JOIN FPA_CALCULOFOLHA CF
    ON ITC.NRCALCULOFOLHA = CF.NRCALCULOFOLHA
        AND CF.NRORG = ITC.NRORG
JOIN FPA_EVENTOH EH
    ON EH.NREVENTOM = ITC.NREVENTOM
        AND (EH.NRORG = :P_NRORG
        OR EH.NRORG = 0)
        AND EH.DTMESCOMPETENC = 
    (SELECT MAX(EHH.DTMESCOMPETENC)
    FROM FPA_EVENTOH EHH
    WHERE EHH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
            AND EHH.NREVENTOM = EH.NREVENTOM
            AND EHH.NRORG = EH.NRORG)
LEFT JOIN VAB_BENEFICIARIO BF
    ON BF.NRVINCULOM = ITC.NRVINCULOM
        AND BF.NRORG = ITC.NRORG
        AND BF.IDTPBENEFICIARIO = 'T'
LEFT JOIN VAB_BENEFICIOH BH
    ON BH.NRBENEFICIOM = BF.NRBENEFICIOM
        AND BH.NRORG = BF.NRORG
        AND BH.DTMESCOMPETENC = 
    (SELECT MAX(BHH.DTMESCOMPETENC)
    FROM VAB_BENEFICIOH BHH
    WHERE BHH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
            AND BHH.NRBENEFICIOM = BH.NRBENEFICIOM
            AND BHH.NRORG = BH.NRORG)
LEFT JOIN ESTRUTURAM EM
    ON EM.NRESTRUTURAM = BH.NRESTRUTURAM
        AND EM.NRORG = :P_NRORG
LEFT JOIN ESTRUTURAH ET
    ON ET.NRESTRUTURAM = EM.NRESTRUTURAM
        AND ET.NRORG = EM.NRORG
        AND ET.DTMESCOMPETENC = 
    (SELECT MAX(DTMESCOMPETENC)
    FROM ESTRUTURAH
    WHERE ESTRUTURAH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
            AND ESTRUTURAH.NRESTRUTURAM = ET.NRESTRUTURAM
            AND ESTRUTURAH.NRORG = ET.NRORG)
WHERE ITC.NRVINCULOM = :P_CHAVE
        AND ITC.NRORG = :P_NRORG
        AND ITC.NRCALCULOFOLHA = :P_NRCALCULOFOLHA
        AND EH.NRNATURUBR = '9219'
SQL;
        $params = array(
            "P_NRORG" => $nrorg,
            "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
            "P_NRCALCULOFOLHA" => $nrcalculofolha,
            "P_CHAVE" => $nrvinculom
        );
        return $this->connection->fetchAll($sql, $params);
    }
    
    public function getDadosS2299detPlano($nrorg, $nrvinculom, $nrbeneficiom, $ntitemcalcfolha) {
        $sql = <<<SQL
SELECT TR.CDESOCIAL AS tpDep,
        PH.NRCPFPESSOA AS cpfDep,
        PH.NMPESSOA AS nmDep,
        PH.DTNASCPESSOA AS dtNascto,
        ITC.VREVENTOFOLHA / ITC.VRREFFOLHA AS vlrPgDep
FROM VAB_BENEFICIARIO B 
JOIN GPE_PESSOA PE ON B.NRPESSOA = PE.NRPESSOA
                    AND B.NRORG    = PE.NRORG
JOIN GPE_PESSOAH PH ON PE.NRPESSOA = PH.NRPESSOA
                     AND PE.NRORG    = PH.NRORG
                     AND PH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_PESSOAH
                                               WHERE GPE_PESSOAH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                 AND GPE_PESSOAH.NRPESSOA = PH.NRPESSOA
                                                 AND GPE_PESSOAH.NRORG = PH.NRORG)
JOIN RELACIONAPARC RP ON RP.NRPARCNEGRELAC = PE.NRPESSOA 
AND RP.NRORG = :P_NRORG 
JOIN TIPORELACIONA TR ON TR.NRTIPORELACIONA = RP.NRTIPORELACIONA
JOIN FPA_ITECALCFOLHA ITC ON ITC.NRVINCULOM = B.NRVINCULOM
AND ITC.NRORG = :P_NRORG 
AND ITC.NRITEMCALCFOLHA = :P_NRITEMCALCFOLHA
WHERE B.NRBENEFICIOM = :P_NRBENEFICIOM 
AND B.NRVINCULOM = :P_CHAVE
AND B.IDTPBENEFICIARIO = 'D'
AND B.NRORG = :P_NRORG
SQL;
        $params = array(
            "P_NRORG" => $nrorg,
            "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
            "P_CHAVE" => $nrvinculom,
            "P_NRBENEFICIOM" => $nrbeneficiom,
            "P_NRITEMCALCFOLHA" => $ntitemcalcfolha
        );
        return $this->connection->fetchAll($sql, $params);
    }
    
     public function getDadosS2299procJudTrab($nrorg, $nrParcnegocio, $nrestrutura) {
        $sql = <<<SQL
SELECT AD.CDESOCIAL AS tpTrib,
       PA.NRPROCESSADMJUD AS nrProcJud,
       IPA.NRSUSPEXIGITPROC AS codSusp
FROM GPE_PROCESSADMJUD PA
INNER JOIN GPE_ITEMPROCADMJUD IPA
ON PA.NRORG            = IPA.NRORG
AND PA.NRPROCESSADMJUD = IPA.NRPROCESSADMJUD
LEFT JOIN GPE_ABDECISAO AD
ON (AD.NRORG         = IPA.NRORG
OR AD.NRORG          = 0)
AND AD.NRABDECISAO   = IPA.NRABDECISAO
WHERE PA.NRORG       = :P_NRORG
AND PA.NRESTRUTURAM  = :P_NRESTRUTURAM
AND PA.NRPARCNEGOCIO = :P_NRPARCNEGOCIO
SQL;
        $params = array(
            "P_NRORG" => $nrorg,
            "P_NRPARCNEGOCIO" => $nrParcnegocio,
            "P_NRESTRUTURAM" => $nrestrutura
        );
        return $this->connection->fetchAll($sql, $params);
    }
    
    public function getDadosS2299remunOutrEmpr($nrorg, $nrvinculom, $nrPessoa) {
        $sql = <<<SQL
SELECT 
DECODE(PN.CDTIPOINSCRICAO,'CNPJ','1','CPF','2','') AS tpInsc,
CASE WHEN EH.CDNATUJURI IN ('1015','1040','1074','1163') THEN PN.NRINSCRICAOPARC ELSE SUBSTR(PN.NRINSCRICAOPARC,1,8) END nrInsc,
EM.NRESTRUTURAM AS codLotacao,
1 AS vlrRemunOE
FROM GPE_VINCULOM VM
JOIN GPE_VINCULOH VH
ON VH.NRVINCULOM      = VM.NRVINCULOM
AND VH.NRORG          = VM.NRORG
AND VH.DTMESCOMPETENC =
  (SELECT MAX(DTMESCOMPETENC)
  FROM GPE_VINCULOH
  WHERE GPE_VINCULOH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
  AND GPE_VINCULOH.NRVINCULOM        = VH.NRVINCULOM
  AND GPE_VINCULOH.NRORG             = VH.NRORG
  )
JOIN ESTRUTURAM EM
ON EM.NRORG          = VM.NRORG
AND VH.NRESTRUTLEGAL = EM.NRESTRUTURAM
JOIN ESTRUTURAH EH
ON EH.NRESTRUTURAM    = EM.NRESTRUTURAM
AND EH.NRORG          = EM.NRORG
AND EH.DTMESCOMPETENC =
  (SELECT MAX(EHH.DTMESCOMPETENC)
  FROM ESTRUTURAH EHH
  WHERE EHH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
  AND EHH.NRESTRUTURAM      = EH.NRESTRUTURAM
  AND EHH.NRORG             = EH.NRORG
  )
LEFT JOIN CLASSTRIBUT CT
ON CT.NRCLASSTRIBUT = EH.NRCLASSTRIBUT
JOIN PARCNEGOCIO PN
ON PN.NRORG             = EM.NRORG
AND PN.NRPARCNEGOCIO    = EM.NRPARCNEGOCIO
WHERE VM.NRPESSOA       = :P_NRPESSOA
AND VM.NRORG            = :P_NRORG
AND VM.NRVINCULOM      != :P_CHAVE
AND (VM.DTRESCISAOVINC IS NULL
OR VM.DTRESCISAOVINC   >= :P_DTMESCOMPETENC)
SQL;
        $params = array(
            "P_NRORG" => $nrorg,
            "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
            "P_CHAVE" => $nrvinculom,
            "P_NRPESSOA" => $nrPessoa
        );
        return $this->connection->fetchAll($sql, $params);
    }
    
     /**
     * @param $nrenvio
     * @param $nrchave
     * @param $nrestruturam
     * @return array    Associative array
     */
    public function getDadosS2306($nrenvio, $nrchave, $nrestruturam) {
        $sql = <<<SQL
SELECT VM.NRVINCULOM CHAVE,
       'ID'||DECODE(PAR.CDTIPOINSCRICAO,'CNPJ','1','CPF','2','')||RPAD(CASE WHEN EMH.CDNATUJURI IN ('1015','1040','1074','1163') THEN PAR.NRINSCRICAOPARC ELSE SUBSTR(PAR.NRINSCRICAOPARC,1,8) END,14,'0')||TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS')||LPAD(:P_NRENVIO,5,'0') id,
       --ideEmpregador
       DECODE(PAR.CDTIPOINSCRICAO,'CNPJ','1','CPF','2','') tpInsc,
           CASE WHEN EMH.CDNATUJURI IN ('1015','1040','1074','1163') THEN PAR.NRINSCRICAOPARC ELSE SUBSTR(PAR.NRINSCRICAOPARC,1,8) END nrInsc,           
       --ideTrabSemVinculo
       REPLACE(REPLACE(PH.NRCPFPESSOA, '.'), '-') AS CPFTRAB,  
       PH.NRPISPASEPPES nisTrab,
       CE.CDESOCIAL codCateg,       
       --infoTSVAlteracao
       TO_CHAR(VH.DTINCLUSAO,'YYYY-MM-DD') dtInicio,
       CASE WHEN VM.NRVINCULOEMPREG IN ('3','4','12','13') THEN '2' ELSE '1' END natAtividade,
       --infoComplementares
       --cargoFuncao
       VH.NRCARGO codCargo,
       VH.NRFUNCAO codFuncao,
       --remuneracao
       SL.VRSALARIO vrSalFx,
       DECODE(SL.IDTPSALARIO,'HORA','1','DIARIO','2','SEMANAL','3','QUINZENAL','4','MENSAL','5','TAREFA','6','7') undSalFixo,
       SUBSTR(SL.DSOBSERVACAO,1,90) dscSalVar,
       --infoEstagiario
       DECODE(CE.CDESOCIAL,'901','N','') natEstagio,
       DECODE(CE.CDESOCIAL,'901',DECODE(GI.CDESOCIAL,'02','1','03','1','04','1','05','1','06','2','07','2','08','4','09','4','8'),'') nivEstagio,
       DECODE(CE.CDESOCIAL,'901','','') areaAtuacao,
       DECODE(CE.CDESOCIAL,'901','','') nrApol,
       DECODE(CE.CDESOCIAL,'901',SL.VRSALARIO,'') vlrBolsa,
       DECODE(CE.CDESOCIAL,'901',TO_CHAR(VH.DTFIMCONTRDETERMIN,'YYYY-MM-DD'),'') dtPrevTerm,
       --instEnsino
       IEH.CDCNPJESTRUT cnpjInstEnsino,
       IEH.NMRAZSOCESTRUT nmRazao,
       IEE.DSENDERECO instEnsino_dscLograd,
       IEE.NRIMOVELENDERECO instEnsino_nrLograd,
       IEE.NMBAIRROENDERECO instEnsino_bairro,
       IEE.NRCEPENDERECO instEnsino_cep,
       MIE.CDMUNICIBGE instEnsino_codMunic,
       IEE.SGESTADO instEnsino_uf,
       --ageIntegracao
       --supervisorEstagio
       PNS.NRINSCRICAOPARC cpfSupervisor,
       PNS.NMPRINCIPALPARC nmSuperv,
       PE.NRORG, PE.NRPARCNEGOCIO
  FROM GPE_VINCULOM VM
  JOIN GPE_VINCULOEMPREG VE ON VE.NRVINCULOEMPREG = VM.NRVINCULOEMPREG
  LEFT JOIN GPE_CATEGTRABESOC CE ON CE.NRCATEGESOC = VE.NRCATEGESOC
  JOIN GPE_TIPOVINCULOH VT ON VT.NRTIPOVINCULOM = VM.NRTIPOVINCULOM
                          AND (VT.NRORG = VM.NRORG OR VT.NRORG = 0 OR VT.NRORG IS NULL)
                          AND VT.IDVINCULOEMPR = 'S'
                          AND VT.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_TIPOVINCULOH
                                                    WHERE GPE_TIPOVINCULOH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                      AND GPE_TIPOVINCULOH.NRTIPOVINCULOM = VT.NRTIPOVINCULOM
                                                      AND GPE_TIPOVINCULOH.NRORG = VT.NRORG)
  JOIN GPE_VINCULOH VH ON VH.NRVINCULOM = VM.NRVINCULOM
                      AND VH.NRORG = VM.NRORG
                      AND VH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_VINCULOH
                                                WHERE GPE_VINCULOH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                  AND GPE_VINCULOH.NRVINCULOM = VH.NRVINCULOM
                                                  AND GPE_VINCULOH.NRORG = VH.NRORG)
  /*Local de Trabalho*/
  JOIN ESTRUTURAH ET ON ET.NRESTRUTURAM = VH.NRESTRUTGEREN
                    AND ET.NRORG = VH.NRORG
                    AND ET.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH
                                              WHERE ESTRUTURAH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                AND ESTRUTURAH.NRESTRUTURAM = ET.NRESTRUTURAM
                                                AND ESTRUTURAH.NRORG = ET.NRORG)
  JOIN PARCNEGOCIO PN ON PN.NRPARCNEGOCIO = ET.NRPARCNEGOCIO
                     AND PN.NRORG = ET.NRORG
  /*Supervisor Estagio*/
  LEFT JOIN PARCNEGOCIO PNS ON PNS.NRPARCNEGOCIO = ET.NRPARCRESPINF
                           AND PNS.NRORG = ET.NRORG
  /*Dados do Empregado - Dependentes*/
  JOIN GPE_PESSOA PE ON VM.NRPESSOA = PE.NRPESSOA
                    AND VM.NRORG    = PE.NRORG
  JOIN GPE_PESSOAH PH ON PE.NRPESSOA = PH.NRPESSOA
                     AND PE.NRORG    = PH.NRORG
                     AND PH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_PESSOAH
                                               WHERE GPE_PESSOAH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                 AND GPE_PESSOAH.NRPESSOA = PH.NRPESSOA
                                                 AND GPE_PESSOAH.NRORG = PH.NRORG)
  LEFT JOIN PAIS PA ON PA.CDPAIS = PH.CDPAIS
                   AND (PA.NRORG = PH.NRORG OR PA.NRORG = 0)
  /*Dados do Empregado - Naturalidade*/
  LEFT JOIN MUNICIPIO MU ON MU.CDMUNICIPIO = PH.CDMUNICIPIO
                        AND (MU.NRORG = PH.NRORG OR MU.NRORG = 0)
  LEFT JOIN GPE_NACIONALIDADE NA ON PH.NRNACIONALID = NA.NRNACIONALIDADE
                                AND (PH.NRORG = NA.NRORG OR NA.NRORG = 0)
  LEFT JOIN PAIS PB ON PB.CDPAIS = NA.CDPAIS
                   AND (PB.NRORG = NA.NRORG OR PB.NRORG = 0)
  /*Endereço Principal*/
  LEFT JOIN ENDERECOPARC EP ON PE.NRPARCNEGOCIO = EP.NRPARCNEGOCIO
                           AND PE.NRORG = EP.NRORG
                           AND EP.CDTIPOENDERECO = 'PRINCIPAL'
  LEFT JOIN MUNICIPIO MP ON MP.CDMUNICIPIO = EP.CDMUNICIPIO
                        AND (MP.NRORG = EP.NRORG OR MP.NRORG = 0)
  /*Endereço Exterior*/
  LEFT JOIN ENDERECOPARC EE ON PE.NRPARCNEGOCIO = EE.NRPARCNEGOCIO
                           AND PE.NRORG = EE.NRORG
                           AND EE.CDTIPOENDERECO = 'EXTERIOR'
  LEFT JOIN MUNICIPIO ME ON ME.CDMUNICIPIO = EE.CDMUNICIPIO
                        AND (ME.NRORG = EE.NRORG OR ME.NRORG = 0)
  LEFT JOIN PAIS PC ON PC.CDPAIS = EE.CDPAIS
                   AND (PC.NRORG = EE.NRORG OR PC.NRORG = 0)
  /*Trabalhador Estrangeiro*/
  LEFT JOIN GPE_CLASSESTRANG CT ON CT.NRCLASSESTRANG = PH.NRCLASSESTRANG
  /*Cargo*/
  LEFT JOIN GPE_OCUPACAOH OH ON OH.NROCUPACAOM = VH.NRCARGO
                            AND OH.NRORG = VH.NRORG
                            AND OH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_OCUPACAOH
                                                      WHERE GPE_OCUPACAOH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                        AND GPE_OCUPACAOH.NROCUPACAOM = OH.NROCUPACAOM
                                                        AND GPE_OCUPACAOH.NRORG = OH.NRORG)
  /*Salário*/
  LEFT JOIN GPE_ALTESALARIO SL ON SL.NRVINCULOM = VM.NRVINCULOM
                              AND SL.NRORG = VM.NRORG
                              AND SL.DTALTESALARIO = (SELECT MAX(DTALTESALARIO) FROM GPE_ALTESALARIO
                                                       WHERE GPE_ALTESALARIO.DTALTESALARIO <= LAST_DAY(:P_DTMESCOMPETENC)
                                                         AND GPE_ALTESALARIO.NRVINCULOM = SL.NRVINCULOM
                                                         AND GPE_ALTESALARIO.NRORG = SL.NRORG)
                              AND SL.NROCORRENCIA =  (SELECT MAX(NROCORRENCIA) FROM GPE_ALTESALARIO
                                                       WHERE GPE_ALTESALARIO.DTALTESALARIO = SL.DTALTESALARIO
                                                         AND GPE_ALTESALARIO.NRVINCULOM = SL.NRVINCULOM
                                                         AND GPE_ALTESALARIO.NRORG = SL.NRORG)
  /*Horário*/
  LEFT JOIN GPE_ESCALATRABH EH ON EH.NRESCALATRABM = VH.NRESCALATRABM
                              AND EH.NRORG = VH.NRORG
                              AND EH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_ESCALATRABH
                                                        WHERE GPE_ESCALATRABH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                          AND GPE_ESCALATRABH.NRESCALATRABM = EH.NRESCALATRABM
                                                          AND GPE_ESCALATRABH.NRORG = EH.NRORG)
  LEFT JOIN PTO_TIPOJORNADA TJ ON TJ.NRTPJORNADA = EH.NRTPJORNADA
                              AND (TJ.NRORG = EH.NRORG OR TJ.NRORG = 0)
  /*Afastamento*/
  LEFT JOIN GPE_ALTESITUFUNC SF ON SF.NRVINCULOM = VH.NRVINCULOM
                               AND SF.NRORG = VH.NRORG
                               AND SYSDATE BETWEEN SF.DTINISITUFUNC AND NVL(SF.DTFIMSITUFUNC,SYSDATE)
                               AND SF.NRSITUFUNCM NOT IN (1,13)
                               AND SF.NRMOTIVOAFASTA IS NOT NULL
  LEFT JOIN GPE_MOTIVOAFASTA MA ON MA.NRMOTIVOAFASTA = SF.NRMOTIVOAFASTA
                               AND (MA.NRORG = SF.NRORG OR MA.NRORG = 0)
  /*Sindicato*/
  LEFT JOIN ESTRUTURAH ES ON ES.NRESTRUTURAM = VH.NRESTRUTSIND
                         AND ES.NRORG = VH.NRORG
                         AND ES.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH
                                                   WHERE ESTRUTURAH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                     AND ESTRUTURAH.NRESTRUTURAM = ES.NRESTRUTURAM
                                                     AND ESTRUTURAH.NRORG = ES.NRORG)
  /*RaçaCor*/
  LEFT JOIN GPE_RACAPESSOA RP ON RP.NRRACAPESSOA = PH.NRRACAPESSOA
                             AND (RP.NRORG = PH.NRORG OR RP.NRORG = 0)
  /*Estado Civil*/
  LEFT JOIN ESTADOCIVIL EC ON EC.CDESTACIVIL = PH.CDESTACIVIL
                          AND (EC.NRORG = PH.NRORG OR EC.NRORG = 0)
  /*Grau Instrução*/
  LEFT JOIN GPE_GRAUINSTR GI ON GI.NRGRAUINSTR = PH.NRGRAUINSTR
                            AND (GI.NRORG = PH.NRORG OR GI.NRORG = 0)
  /*Logradouro*/
  LEFT JOIN LOGRADOURO LG ON LG.CDLOGRADOURO = EP.CDLOGRADOURO
                         AND (LG.NRORG = EP.NRORG OR LG.NRORG = 0)
  /*Instituição Ensino*/
  LEFT JOIN DES_FORMACAO FO ON FO.NRORG = PE.NRORG
                           AND FO.NRPARCNEGOCIO = PE.NRPARCNEGOCIO
                           AND FO.DTINICIO = (SELECT MAX(DTINICIO) FROM DES_FORMACAO
                                               WHERE NRORG = PE.NRORG
                                                 AND NRPARCNEGOCIO = PE.NRPARCNEGOCIO
                                                 AND DTINICIO <= :P_DTMESCOMPETENC
                                                 AND (DTFIM IS NULL OR DTFIM >=:P_DTMESCOMPETENC))
  LEFT JOIN ESTRUTURAH IEH ON IEH.NRORG = FO.NRORG
                          AND IEH.NRESTRUTURAM = FO.NRESTRUTURAM
                          AND IEH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH
                                                     WHERE DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                       AND NRESTRUTURAM = IEH.NRESTRUTURAM
                                                       AND NRORG = IEH.NRORG)
  LEFT JOIN ENDERECOPARC IEE ON IEE.NRPARCNEGOCIO = IEH.NRPARCNEGOCIO
                            AND IEE.NRORG = IEH.NRORG
                            AND IEE.CDTIPOENDERECO = 'PRINCIPAL'
  LEFT JOIN MUNICIPIO MIE ON MIE.CDMUNICIPIO = IEE.CDMUNICIPIO
                         AND (MIE.NRORG = IEE.NRORG OR MIE.NRORG = 0)
  LEFT JOIN PAIS PIE ON PIE.CDPAIS = IEE.CDPAIS
                    AND (PIE.NRORG = IEE.NRORG OR PC.NRORG = 0)
  /*Empregador*/
  JOIN ESTRUTURAH EMH ON EMH.NRORG = :P_NRORG
                     AND EMH.NRESTRUTURAM = :P_NRESTRUTURAM
                     AND EMH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH
                                                WHERE DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                  AND NRESTRUTURAM = EMH.NRESTRUTURAM
                                                  AND NRORG = EMH.NRORG)
  JOIN PARCNEGOCIO PAR ON PAR.NRPARCNEGOCIO = EMH.NRPARCNEGOCIO
                      AND PAR.NRORG = EMH.NRORG
 WHERE VM.NRORG = :P_NRORG
   AND VH.NRESTRUTLEGAL = :P_NRESTRUTURAM
   AND (VM.DTRESCISAOVINC IS NULL OR VM.DTRESCISAOVINC >= :P_DTMESCOMPETENC)
   AND VM.NRTIPOVINCULOM IN (2,3,10) --Estagiario, Socio, Autonomo
   AND VM.NRVINCULOM = :P_NRCHAVE
SQL;
        $params = array(
            "P_NRORG" => $this->hcmParameters->getNrorgTrabalho(),
            "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
            "P_NRENVIO" => $nrenvio,
            "P_NRCHAVE" => $nrchave,
            "P_NRESTRUTURAM" => $nrestruturam
        );
        return $this->connection->fetchAssoc($sql, $params);
    }
    
     /**
     * @param $nrenvio
     * @param $nrchave
     * @param $nrestruturam
     * @return array    Associative array
     */
    public function getDadosS2399($nrenvio, $nrchave, $nrestruturam) {
        $sql = <<<SQL
SELECT VM.NRVINCULOM CHAVE,
       'ID'||DECODE(PAR.CDTIPOINSCRICAO,'CNPJ','1','CPF','2','')||RPAD(CASE WHEN ET.CDNATUJURI IN ('1015','1040','1074','1163') THEN PAR.NRINSCRICAOPARC ELSE SUBSTR(PAR.NRINSCRICAOPARC,1,8) END,14,'0')||TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS')||LPAD(:P_NRENVIO,5,'0') id,
       --ideEmpregador
       DECODE(PAR.CDTIPOINSCRICAO,'CNPJ','1','CPF','2','') tpInsc,
           CASE WHEN ET.CDNATUJURI IN ('1015','1040','1074','1163') THEN PAR.NRINSCRICAOPARC ELSE SUBSTR(PAR.NRINSCRICAOPARC,1,8) END nrInsc,
       --ideTrabSemVinculo
       REPLACE(REPLACE(PH.NRCPFPESSOA, '.'), '-') AS CPFTRAB,  
       PH.NRPISPASEPPES nisTrab,
       CE.CDESOCIAL codCateg,
       --infoTSVTermino
       TO_CHAR(VM.DTRESCISAOVINC,'YYYY-MM-DD') dtTerm,
       TD.CDESOCIAL mtvDesligTSV,       
       --dmDev getDadosS2399dmDev       
       --ideEstabLot getDadosS2399ideEstabLot       
       --detVerbas getDadosS2399detVerbas       
       --detOper getDadosS2399detOper       
       --detPlano getDadosS2399detPlano       
       --procJudTrab getDadosS2399procJudTrab       
       --infoMV
       --getDadosS2399remunOutrEmpr
       1 AS indMV,
       null dtFimQuar              
  FROM GPE_VINCULOM VM
  JOIN GPE_VINCULOEMPREG VE ON VE.NRVINCULOEMPREG = VM.NRVINCULOEMPREG
  LEFT JOIN GPE_CATEGTRABESOC CE ON CE.NRCATEGESOC = VE.NRCATEGESOC
  JOIN GPE_VINCULOH VH ON VH.NRVINCULOM = VM.NRVINCULOM
                      AND VH.NRORG = VM.NRORG
                      AND VH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_VINCULOH
                                                WHERE GPE_VINCULOH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                  AND GPE_VINCULOH.NRVINCULOM = VH.NRVINCULOM
                                                  AND GPE_VINCULOH.NRORG = VH.NRORG)
  /*Local de Trabalho*/
  JOIN ESTRUTURAH ET ON ET.NRESTRUTURAM = VH.NRESTRUTGEREN
                    AND ET.NRORG = VH.NRORG
                    AND ET.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH
                                              WHERE ESTRUTURAH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                AND ESTRUTURAH.NRESTRUTURAM = ET.NRESTRUTURAM
                                                AND ESTRUTURAH.NRORG = ET.NRORG)
  JOIN PARCNEGOCIO PN ON PN.NRPARCNEGOCIO = ET.NRPARCNEGOCIO
                     AND PN.NRORG = ET.NRORG
  /*Tipo Demissao*/                   
  JOIN FPA_TPDEMISSAO TD ON VM.NRTPDEMISSAO = TD.NRTPDEMISSAO 
    AND (TD.NRORG = :P_NRORG OR TD.NRORG = 0)                   
  JOIN GPE_PESSOA PE ON VM.NRPESSOA = PE.NRPESSOA
                    AND VM.NRORG    = PE.NRORG
  JOIN GPE_PESSOAH PH ON PE.NRPESSOA = PH.NRPESSOA
                     AND PE.NRORG    = PH.NRORG
                     AND PH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_PESSOAH
                                               WHERE GPE_PESSOAH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                 AND GPE_PESSOAH.NRPESSOA = PH.NRPESSOA
                                                 AND GPE_PESSOAH.NRORG = PH.NRORG)  
  LEFT JOIN GPE_CLASSESTRANG CT ON CT.NRCLASSESTRANG = PH.NRCLASSESTRANG 
  JOIN PARCNEGOCIO PAR ON PAR.NRPARCNEGOCIO = ET.NRPARCNEGOCIO
                      AND PAR.NRORG = ET.NRORG
 WHERE VM.NRORG = :P_NRORG
   AND VH.NRESTRUTLEGAL = :P_NRESTRUTURAM   
   AND VM.NRTIPOVINCULOM IN (2,3,10) --Estagiario, Socio, Autonomo
   AND VM.NRVINCULOM = :P_NRCHAVE
SQL;
        $params = array(
            "P_NRORG" => $this->hcmParameters->getNrorgTrabalho(),
            "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
            "P_NRENVIO" => $nrenvio,
            "P_NRCHAVE" => $nrchave,
            "P_NRESTRUTURAM" => $nrestruturam
        );
        return $this->connection->fetchAssoc($sql, $params);
    }
    
    public function getDadosS2399dmDev($nrorg, $dtrescisao, $nrvinculom) {
        $sql = <<<SQL
SELECT ITC.NRCALCULOFOLHA AS ideDmDev
FROM FPA_ITECALCFOLHA ITC
WHERE ITC.NRVINCULOM     = :P_CHAVE
AND ITC.NRORG = :P_NRORG and
ITC.NREVENTOM = '3050'
AND ITC.DTOCORRENCIA =
  (SELECT MAX(ITCH.DTOCORRENCIA)
  FROM FPA_ITECALCFOLHA ITCH
  WHERE ITCH.NRORG       = ITC.NRORG
  AND ITCH.NRVINCULOM = ITC.NRVINCULOM
  AND
  ITCH.NREVENTOM = '3050' AND ITCH.DTOCORRENCIA <= :P_DTRESCISAOVINC)
SQL;
        $params = array(
            "P_NRORG" => $nrorg,
            "P_DTRESCISAOVINC" => $dtrescisao,
            "P_CHAVE" => $nrvinculom
        );
        return $this->connection->fetchAll($sql, $params);
    }
    
    public function getDadosS2399ideEstabLot($nrorg, $nrestruturaMovimentada) {
        $sql = <<<SQL
SELECT 
NVL(DECODE(PNSUP.CDTIPOINSCRICAO,'CNPJ','1','CPF','2',''), 
DECODE(PN.CDTIPOINSCRICAO,'CNPJ','1','CPF','2','')) AS tpInsc,
CASE WHEN EH.CDNATUJURI IN ('1015','1040','1074','1163') THEN NVL(PNSUP.NRINSCRICAOPARC, PN.NRINSCRICAOPARC) ELSE NVL(SUBSTR(PNSUP.NRINSCRICAOPARC,1,8),  SUBSTR(PN.NRINSCRICAOPARC,1,8)) END nrInsc,
NVL(EMSUP.NRESTRUTURAM, EM.NRESTRUTURAM) AS codLotacao,
1 AS grauExp,
DECODE(NVL(CTSUP.CDESOCIAL,CT.CDESOCIAL),'01','1','02','2','03','3','') AS indSimples

FROM ESTRUTURAM EM
JOIN ESTRUTURAH EH ON EH.NRESTRUTURAM = EM.NRESTRUTURAM
                    AND EH.NRORG = EM.NRORG
                    AND EH.DTMESCOMPETENC = (SELECT MAX(EHH.DTMESCOMPETENC) FROM ESTRUTURAH EHH
                                              WHERE EHH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                AND EHH.NRESTRUTURAM = EH.NRESTRUTURAM
                                                AND EHH.NRORG = EH.NRORG)
LEFT JOIN CLASSTRIBUT CT 
ON CT.NRCLASSTRIBUT = EH.NRCLASSTRIBUT                                                
JOIN PARCNEGOCIO PN ON 
PN.NRORG = EM.NRORG AND 
PN.NRPARCNEGOCIO = EM.NRPARCNEGOCIO
JOIN HIERARQUIAORG HO
ON HO.NRESTRUTURAMREL = EM.NRESTRUTURAM
AND HO.NRORG          = EM.NRORG
LEFT JOIN ESTRUTURAM EMSUP
ON EMSUP.NRESTRUTURAM     = HO.NRESTRUTURAMSUP
AND EMSUP.NRORG           = EM.NRORG
AND EMSUP.NRTIPOESTRUTURA = '4'
LEFT JOIN ESTRUTURAH EHSUP ON EHSUP.NRESTRUTURAM = EM.NRESTRUTURAM
                    AND EHSUP.NRORG = EM.NRORG
                    AND EHSUP.DTMESCOMPETENC = (SELECT MAX(EHHSUP.DTMESCOMPETENC) FROM ESTRUTURAH EHHSUP
                                              WHERE EHHSUP.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                AND EHHSUP.NRESTRUTURAM = EH.NRESTRUTURAM
                                                AND EHHSUP.NRORG = EH.NRORG)
LEFT JOIN CLASSTRIBUT CTSUP 
ON CTSUP.NRCLASSTRIBUT = EHSUP.NRCLASSTRIBUT
LEFT JOIN PARCNEGOCIO PNSUP
ON PNSUP.NRPARCNEGOCIO = EMSUP.NRPARCNEGOCIO 
AND PNSUP.NRORG = EMSUP.NRORG
WHERE EM.NRORG            = :P_NRORG
AND EM.NRESTRUTURAM       = :P_NRESTRUTURAM
SQL;
        $params = array(
            "P_NRORG" => $nrorg,
            "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
            "P_NRESTRUTURAM" => $nrestruturaMovimentada
        );
        return $this->connection->fetchAll($sql, $params);
    }
    
    public function getDadosS2399detVerbas($nrorg, $nrvinculom, $nrcalculofolha) {
        $sql = <<<SQL
SELECT ITC.NREVENTOM AS codRubr,
  CF.NRTIPOMOVIMENT  AS ideTabRubr,
  ITC.VRREFFOLHA     AS qtdRubr,
  EH.VRPERCENTUALEVENTO  AS fatorRubr,
  DECODE(ITC.VRREFFOLHA,'0', '', TO_CHAR(ITC.VREVENTOFOLHA / ITC.VRREFFOLHA, '9G999D99')) AS vrUnit,
  ITC.VREVENTOFOLHA AS vrRubr
FROM FPA_ITECALCFOLHA ITC
JOIN FPA_CALCULOFOLHA CF
ON ITC.NRCALCULOFOLHA = CF.NRCALCULOFOLHA
AND CF.NRORG          = ITC.NRORG
JOIN FPA_EVENTOH EH
ON EH.NREVENTOM        = ITC.NREVENTOM
AND (EH.NRORG = :P_NRORG OR EH.NRORG = 0)
AND EH.DTMESCOMPETENC  = (SELECT MAX(EHH.DTMESCOMPETENC) FROM FPA_EVENTOH EHH
                                                         WHERE EHH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                           AND EHH.NREVENTOM = EH.NREVENTOM
                                                           AND EHH.NRORG = EH.NRORG)
WHERE ITC.NRVINCULOM   = :P_CHAVE
AND ITC.NRORG          = :P_NRORG
AND ITC.NRCALCULOFOLHA = :P_NRCALCULOFOLHA
SQL;
        $params = array(
            "P_NRORG" => $nrorg,
            "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
            "P_CHAVE" => $nrvinculom,
            "P_NRCALCULOFOLHA" => $nrcalculofolha
        );
        return $this->connection->fetchAll($sql, $params);
    }
    
    public function getDadosS2399detOper($nrorg, $nrcalculofolha, $nrvinculom) {
        $sql = <<<SQL
SELECT ET.CDCNPJESTRUT AS cnpjOper,
         et.CDFEDERALESTRUT AS regANS,
         ITC.VREVENTOFOLHA AS vrPgTit
FROM FPA_ITECALCFOLHA ITC
JOIN FPA_CALCULOFOLHA CF
    ON ITC.NRCALCULOFOLHA = CF.NRCALCULOFOLHA
        AND CF.NRORG = ITC.NRORG
JOIN FPA_EVENTOH EH
    ON EH.NREVENTOM = ITC.NREVENTOM
        AND (EH.NRORG = :P_NRORG
        OR EH.NRORG = 0)
        AND EH.DTMESCOMPETENC = 
    (SELECT MAX(EHH.DTMESCOMPETENC)
    FROM FPA_EVENTOH EHH
    WHERE EHH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
            AND EHH.NREVENTOM = EH.NREVENTOM
            AND EHH.NRORG = EH.NRORG)
LEFT JOIN VAB_BENEFICIARIO BF
    ON BF.NRVINCULOM = ITC.NRVINCULOM
        AND BF.NRORG = ITC.NRORG
        AND BF.IDTPBENEFICIARIO = 'T'
LEFT JOIN VAB_BENEFICIOH BH
    ON BH.NRBENEFICIOM = BF.NRBENEFICIOM
        AND BH.NRORG = BF.NRORG
        AND BH.DTMESCOMPETENC = 
    (SELECT MAX(BHH.DTMESCOMPETENC)
    FROM VAB_BENEFICIOH BHH
    WHERE BHH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
            AND BHH.NRBENEFICIOM = BH.NRBENEFICIOM
            AND BHH.NRORG = BH.NRORG)
LEFT JOIN ESTRUTURAM EM
    ON EM.NRESTRUTURAM = BH.NRESTRUTURAM
        AND EM.NRORG = :P_NRORG
LEFT JOIN ESTRUTURAH ET
    ON ET.NRESTRUTURAM = EM.NRESTRUTURAM
        AND ET.NRORG = EM.NRORG
        AND ET.DTMESCOMPETENC = 
    (SELECT MAX(DTMESCOMPETENC)
    FROM ESTRUTURAH
    WHERE ESTRUTURAH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
            AND ESTRUTURAH.NRESTRUTURAM = ET.NRESTRUTURAM
            AND ESTRUTURAH.NRORG = ET.NRORG)
WHERE ITC.NRVINCULOM = :P_CHAVE
        AND ITC.NRORG = :P_NRORG
        AND ITC.NRCALCULOFOLHA = :P_NRCALCULOFOLHA
        AND EH.NRNATURUBR = '9219'
SQL;
        $params = array(
            "P_NRORG" => $nrorg,
            "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
            "P_NRCALCULOFOLHA" => $nrcalculofolha,
            "P_CHAVE" => $nrvinculom
        );
        return $this->connection->fetchAll($sql, $params);
    }
    
    public function getDadosS2399detPlano($nrorg, $nrvinculom, $nrbeneficiom, $ntitemcalcfolha) {
        $sql = <<<SQL
SELECT TR.CDESOCIAL AS tpDep,
        PH.NRCPFPESSOA AS cpfDep,
        PH.NMPESSOA AS nmDep,
        PH.DTNASCPESSOA AS dtNascto,
        ITC.VREVENTOFOLHA / ITC.VRREFFOLHA AS vlrPgDep
FROM VAB_BENEFICIARIO B 
JOIN GPE_PESSOA PE ON B.NRPESSOA = PE.NRPESSOA
                    AND B.NRORG    = PE.NRORG
JOIN GPE_PESSOAH PH ON PE.NRPESSOA = PH.NRPESSOA
                     AND PE.NRORG    = PH.NRORG
                     AND PH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_PESSOAH
                                               WHERE GPE_PESSOAH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                 AND GPE_PESSOAH.NRPESSOA = PH.NRPESSOA
                                                 AND GPE_PESSOAH.NRORG = PH.NRORG)
JOIN RELACIONAPARC RP ON RP.NRPARCNEGRELAC = PE.NRPESSOA 
AND RP.NRORG = :P_NRORG 
JOIN TIPORELACIONA TR ON TR.NRTIPORELACIONA = RP.NRTIPORELACIONA
JOIN FPA_ITECALCFOLHA ITC ON ITC.NRVINCULOM = B.NRVINCULOM
AND ITC.NRORG = :P_NRORG 
AND ITC.NRITEMCALCFOLHA = :P_NRITEMCALCFOLHA
WHERE B.NRBENEFICIOM = :P_NRBENEFICIOM 
AND B.NRVINCULOM = :P_CHAVE
AND B.IDTPBENEFICIARIO = 'D'
AND B.NRORG = :P_NRORG
SQL;
        $params = array(
            "P_NRORG" => $nrorg,
            "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
            "P_CHAVE" => $nrvinculom,
            "P_NRBENEFICIOM" => $nrbeneficiom,
            "P_NRITEMCALCFOLHA" => $ntitemcalcfolha,
        );
        return $this->connection->fetchAll($sql, $params);
    }
    
     public function getDadosS2399procJudTrab($nrorg, $nrParcnegocio, $nrestrutura) {
        $sql = <<<SQL
SELECT AD.CDESOCIAL AS tpTrib,
       PA.NRPROCESSADMJUD AS nrProcJud,
       IPA.NRSUSPEXIGITPROC AS codSusp
FROM GPE_PROCESSADMJUD PA
INNER JOIN GPE_ITEMPROCADMJUD IPA
ON PA.NRORG            = IPA.NRORG
AND PA.NRPROCESSADMJUD = IPA.NRPROCESSADMJUD
LEFT JOIN GPE_ABDECISAO AD
ON (AD.NRORG         = IPA.NRORG
OR AD.NRORG          = 0)
AND AD.NRABDECISAO   = IPA.NRABDECISAO
WHERE PA.NRORG       = :P_NRORG
AND PA.NRESTRUTURAM  = :P_NRESTRUTURAM
AND PA.NRPARCNEGOCIO = :P_NRPARCNEGOCIO
SQL;
        $params = array(
            "P_NRORG" => $nrorg,
            "P_NRPARCNEGOCIO" => $nrParcnegocio,
            "P_NRESTRUTURAM" => $nrestrutura
        );
        return $this->connection->fetchAll($sql, $params);
    }
    
    public function getDadosS2399remunOutrEmpr($nrorg, $nrvinculom, $nrPessoa) {
        $sql = <<<SQL
SELECT 
DECODE(PN.CDTIPOINSCRICAO,'CNPJ','1','CPF','2','') AS tpInsc,
CASE WHEN EH.CDNATUJURI IN ('1015','1040','1074','1163') THEN PN.NRINSCRICAOPARC ELSE SUBSTR(PN.NRINSCRICAOPARC,1,8) END nrInsc,
EM.NRESTRUTURAM AS codLotacao,
1 AS vlrRemunOE
FROM GPE_VINCULOM VM
JOIN GPE_VINCULOH VH
ON VH.NRVINCULOM      = VM.NRVINCULOM
AND VH.NRORG          = VM.NRORG
AND VH.DTMESCOMPETENC =
  (SELECT MAX(DTMESCOMPETENC)
  FROM GPE_VINCULOH
  WHERE GPE_VINCULOH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
  AND GPE_VINCULOH.NRVINCULOM        = VH.NRVINCULOM
  AND GPE_VINCULOH.NRORG             = VH.NRORG
  )
JOIN ESTRUTURAM EM
ON EM.NRORG          = VM.NRORG
AND VH.NRESTRUTLEGAL = EM.NRESTRUTURAM
JOIN ESTRUTURAH EH
ON EH.NRESTRUTURAM    = EM.NRESTRUTURAM
AND EH.NRORG          = EM.NRORG
AND EH.DTMESCOMPETENC =
  (SELECT MAX(EHH.DTMESCOMPETENC)
  FROM ESTRUTURAH EHH
  WHERE EHH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
  AND EHH.NRESTRUTURAM      = EH.NRESTRUTURAM
  AND EHH.NRORG             = EH.NRORG
  )
LEFT JOIN CLASSTRIBUT CT
ON CT.NRCLASSTRIBUT = EH.NRCLASSTRIBUT
JOIN PARCNEGOCIO PN
ON PN.NRORG             = EM.NRORG
AND PN.NRPARCNEGOCIO    = EM.NRPARCNEGOCIO
WHERE VM.NRPESSOA       = :P_NRPESSOA
AND VM.NRORG            = :P_NRORG
AND VM.NRVINCULOM      != :P_CHAVE
AND (VM.DTRESCISAOVINC IS NULL
OR VM.DTRESCISAOVINC   >= :P_DTMESCOMPETENC)
SQL;
        $params = array(
            "P_NRORG" => $nrorg,
            "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
            "P_CHAVE" => $nrvinculom,
            "P_NRPESSOA" => $nrPessoa
        );
        return $this->connection->fetchAll($sql, $params);
    }
}